# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nifgen.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import nidevice_pb2 as nidevice__pb2
from . import session_pb2 as session__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cnifgen.proto\x12\x0bnifgen_grpc\x1a\x0enidevice.proto\x1a\rsession.proto\"<\n\x16\x41\x62ortGenerationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\")\n\x17\x41\x62ortGenerationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"d\n%AdjustSampleClockRelativeDelayRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0f\x61\x64justment_time\x18\x02 \x01(\x01\"8\n&AdjustSampleClockRelativeDelayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x86\x01\n\x1c\x41llocateNamedWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12\x15\n\rwaveform_size\x18\x04 \x01(\x11\"/\n\x1d\x41llocateNamedWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"j\n\x17\x41llocateWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_size\x18\x03 \x01(\x11\"C\n\x18\x41llocateWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"\xa7\x01\n\x1e\x43heckAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x17\n\x0f\x61ttribute_value\x18\x04 \x01(\x08\"1\n\x1f\x43heckAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x87\x02\n\x1c\x43heckAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x42\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32\'.nifgen_grpc.NiFgenInt32AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x11H\x00\x42\x16\n\x14\x61ttribute_value_enum\"/\n\x1d\x43heckAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa9\x01\n\x1c\x43heckAttributeViInt64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\x03\"/\n\x1d\x43heckAttributeViInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x89\x02\n\x1d\x43heckAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x43\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32(.nifgen_grpc.NiFgenReal64AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x01H\x00\x42\x16\n\x14\x61ttribute_value_enum\"0\n\x1e\x43heckAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbf\x01\n\x1e\x43heckAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12/\n\x0f\x61ttribute_value\x18\x04 \x01(\x0b\x32\x16.nidevice_grpc.Session\"1\n\x1f\x43heckAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x96\x02\n\x1d\x43heckAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x1d\n\x13\x61ttribute_value_raw\x18\x04 \x01(\tH\x00\x12P\n\x16\x61ttribute_value_mapped\x18\x05 \x01(\x0e\x32..nifgen_grpc.NiFgenStringAttributeValuesMappedH\x00\x42\x16\n\x14\x61ttribute_value_enum\"0\n\x1e\x43heckAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\";\n\x15\x43learArbMemoryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"(\n\x16\x43learArbMemoryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xac\x01\n\x17\x43learArbSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\x0fsequence_handle\x18\x02 \x01(\x0e\x32\x1b.nifgen_grpc.SequenceHandleH\x00\x12\x1d\n\x13sequence_handle_raw\x18\x03 \x01(\x11H\x00\x42\x16\n\x14sequence_handle_enum\"*\n\x18\x43learArbSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xac\x01\n\x17\x43learArbWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\x0fwaveform_handle\x18\x02 \x01(\x0e\x32\x1b.nifgen_grpc.WaveformHandleH\x00\x12\x1d\n\x13waveform_handle_raw\x18\x03 \x01(\x11H\x00\x42\x16\n\x14waveform_handle_enum\"*\n\x18\x43learArbWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"7\n\x11\x43learErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"$\n\x12\x43learErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc1\x01\n\x14\x43learFreqListRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x42\n\x15\x66requency_list_handle\x18\x02 \x01(\x0e\x32!.nifgen_grpc.FrequencyListOptionsH\x00\x12#\n\x19\x66requency_list_handle_raw\x18\x03 \x01(\x11H\x00\x42\x1c\n\x1a\x66requency_list_handle_enum\"\'\n\x15\x43learFreqListResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"E\n\x1f\x43learInterchangeWarningsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"2\n ClearInterchangeWarningsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\\\n ClearUserStandardWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"3\n!ClearUserStandardWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"2\n\x0c\x43loseRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rCloseResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"3\n\rCommitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\" \n\x0e\x43ommitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"h\n\x19\x43onfigureAmplitudeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\tamplitude\x18\x03 \x01(\x01\",\n\x1a\x43onfigureAmplitudeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8e\x01\n\x1b\x43onfigureArbSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fsequence_handle\x18\x03 \x01(\x11\x12\x0c\n\x04gain\x18\x04 \x01(\x01\x12\x0e\n\x06offset\x18\x05 \x01(\x01\".\n\x1c\x43onfigureArbSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8e\x01\n\x1b\x43onfigureArbWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fwaveform_handle\x18\x03 \x01(\x11\x12\x0c\n\x04gain\x18\x04 \x01(\x01\x12\x0e\n\x06offset\x18\x05 \x01(\x01\".\n\x1c\x43onfigureArbWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"P\n\x18\x43onfigureChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x10\n\x08\x63hannels\x18\x02 \x01(\t\"+\n\x19\x43onfigureChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9a\x01\n\x19\x43onfigureClockModeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12,\n\nclock_mode\x18\x02 \x01(\x0e\x32\x16.nifgen_grpc.ClockModeH\x00\x12\x18\n\x0e\x63lock_mode_raw\x18\x03 \x01(\x11H\x00\x42\x11\n\x0f\x63lock_mode_enum\",\n\x1a\x43onfigureClockModeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x83\x01\n+ConfigureCustomFIRFilterCoefficientsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1a\n\x12\x63oefficients_array\x18\x03 \x03(\x01\">\n,ConfigureCustomFIRFilterCoefficientsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x80\x01\n(ConfigureDigitalEdgeScriptTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\ntrigger_id\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x0c\n\x04\x65\x64ge\x18\x04 \x01(\x11\";\n)ConfigureDigitalEdgeScriptTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"k\n\'ConfigureDigitalEdgeStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0c\n\x04\x65\x64ge\x18\x03 \x01(\x11\":\n(ConfigureDigitalEdgeStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd6\x01\n)ConfigureDigitalLevelScriptTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\ntrigger_id\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x30\n\x0ctrigger_when\x18\x04 \x01(\x0e\x32\x18.nifgen_grpc.TriggerWhenH\x00\x12\x1a\n\x10trigger_when_raw\x18\x05 \x01(\x11H\x00\x42\x13\n\x11trigger_when_enum\"<\n*ConfigureDigitalLevelScriptTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xae\x01\n\x18\x43onfigureFreqListRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1d\n\x15\x66requency_list_handle\x18\x03 \x01(\x11\x12\x11\n\tamplitude\x18\x04 \x01(\x01\x12\x11\n\tdc_offset\x18\x05 \x01(\x01\x12\x13\n\x0bstart_phase\x18\x06 \x01(\x01\"+\n\x19\x43onfigureFreqListResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"h\n\x19\x43onfigureFrequencyRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\tfrequency\x18\x03 \x01(\x01\",\n\x1a\x43onfigureFrequencyResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n\x1d\x43onfigureOperationModeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0eoperation_mode\x18\x03 \x01(\x11\"0\n\x1e\x43onfigureOperationModeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"j\n\x1d\x43onfigureOutputEnabledRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"0\n\x1e\x43onfigureOutputEnabledResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"n\n\x1f\x43onfigureOutputImpedanceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\timpedance\x18\x03 \x01(\x01\"2\n ConfigureOutputImpedanceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9f\x01\n\x1a\x43onfigureOutputModeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12.\n\x0boutput_mode\x18\x02 \x01(\x0e\x32\x17.nifgen_grpc.OutputModeH\x00\x12\x19\n\x0foutput_mode_raw\x18\x03 \x01(\x11H\x00\x42\x12\n\x10output_mode_enum\"-\n\x1b\x43onfigureOutputModeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"z\n/ConfigureP2PEndpointFullnessStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12#\n\x1bp2p_endpoint_fullness_level\x18\x02 \x01(\x11\"B\n0ConfigureP2PEndpointFullnessStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x87\x01\n\x1e\x43onfigureReferenceClockRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1e\n\x16reference_clock_source\x18\x02 \x01(\t\x12!\n\x19reference_clock_frequency\x18\x03 \x01(\x01\"1\n\x1f\x43onfigureReferenceClockResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"d\n!ConfigureSampleClockSourceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1b\n\x13sample_clock_source\x18\x02 \x01(\t\"4\n\"ConfigureSampleClockSourceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"U\n\x1a\x43onfigureSampleRateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x13\n\x0bsample_rate\x18\x02 \x01(\x01\"-\n\x1b\x43onfigureSampleRateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"c\n)ConfigureSoftwareEdgeScriptTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\ntrigger_id\x18\x02 \x01(\t\"<\n*ConfigureSoftwareEdgeScriptTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"N\n(ConfigureSoftwareEdgeStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\";\n)ConfigureSoftwareEdgeStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xfe\x01\n ConfigureStandardWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12)\n\x08waveform\x18\x03 \x01(\x0e\x32\x15.nifgen_grpc.WaveformH\x00\x12\x16\n\x0cwaveform_raw\x18\x04 \x01(\x11H\x00\x12\x11\n\tamplitude\x18\x05 \x01(\x01\x12\x11\n\tdc_offset\x18\x06 \x01(\x01\x12\x11\n\tfrequency\x18\x07 \x01(\x01\x12\x13\n\x0bstart_phase\x18\x08 \x01(\x01\x42\x0f\n\rwaveform_enum\"3\n!ConfigureStandardWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"{\n\x1f\x43onfigureSynchronizationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1e\n\x16synchronization_source\x18\x03 \x01(\x11\"2\n ConfigureSynchronizationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xba\x01\n\x1b\x43onfigureTriggerModeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0ctrigger_mode\x18\x03 \x01(\x0e\x32\x18.nifgen_grpc.TriggerModeH\x00\x12\x1a\n\x10trigger_mode_raw\x18\x04 \x01(\x11H\x00\x42\x13\n\x11trigger_mode_enum\".\n\x1c\x43onfigureTriggerModeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbd\x01\n CreateAdvancedArbSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1e\n\x16waveform_handles_array\x18\x02 \x03(\x11\x12\x19\n\x11loop_counts_array\x18\x03 \x03(\x11\x12\x1b\n\x13sample_counts_array\x18\x04 \x03(\x11\x12\x1d\n\x15marker_location_array\x18\x05 \x03(\x11\"k\n!CreateAdvancedArbSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1d\n\x15\x63oerced_markers_array\x18\x02 \x03(\x11\x12\x17\n\x0fsequence_handle\x18\x03 \x01(\x11\"y\n\x18\x43reateArbSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1e\n\x16waveform_handles_array\x18\x02 \x03(\x11\x12\x19\n\x11loop_counts_array\x18\x03 \x03(\x11\"D\n\x19\x43reateArbSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fsequence_handle\x18\x02 \x01(\x11\"\xc0\x01\n\x15\x43reateFreqListRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12)\n\x08waveform\x18\x02 \x01(\x0e\x32\x15.nifgen_grpc.WaveformH\x00\x12\x16\n\x0cwaveform_raw\x18\x03 \x01(\x11H\x00\x12\x17\n\x0f\x66requency_array\x18\x04 \x03(\x01\x12\x16\n\x0e\x64uration_array\x18\x05 \x03(\x01\x42\x0f\n\rwaveform_enum\"G\n\x16\x43reateFreqListResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1d\n\x15\x66requency_list_handle\x18\x02 \x01(\x11\"\x98\x01\n\x1f\x43reateWaveformComplexF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12;\n\x13waveform_data_array\x18\x03 \x03(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\"K\n CreateWaveformComplexF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"q\n\x18\x43reateWaveformF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1b\n\x13waveform_data_array\x18\x03 \x03(\x01\"D\n\x19\x43reateWaveformF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"\xca\x01\n CreateWaveformFromFileF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\tfile_name\x18\x03 \x01(\t\x12,\n\nbyte_order\x18\x04 \x01(\x0e\x32\x16.nifgen_grpc.ByteOrderH\x00\x12\x18\n\x0e\x62yte_order_raw\x18\x05 \x01(\x11H\x00\x42\x11\n\x0f\x62yte_order_enum\"L\n!CreateWaveformFromFileF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"\xba\x01\n CreateWaveformFromFileHWSRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\tfile_name\x18\x03 \x01(\t\x12\x1e\n\x16use_rate_from_waveform\x18\x04 \x01(\x08\x12)\n!use_gain_and_offset_from_waveform\x18\x05 \x01(\x08\"L\n!CreateWaveformFromFileHWSResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"\xca\x01\n CreateWaveformFromFileI16Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\tfile_name\x18\x03 \x01(\t\x12,\n\nbyte_order\x18\x04 \x01(\x0e\x32\x16.nifgen_grpc.ByteOrderH\x00\x12\x18\n\x0e\x62yte_order_raw\x18\x05 \x01(\x11H\x00\x42\x11\n\x0f\x62yte_order_enum\"L\n!CreateWaveformFromFileI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"q\n\x18\x43reateWaveformI16Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1b\n\x13waveform_data_array\x18\x03 \x03(\x11\"D\n\x19\x43reateWaveformI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"z\n!DefineUserStandardWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1b\n\x13waveform_data_array\x18\x03 \x03(\x01\"4\n\"DefineUserStandardWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"m\n\x1a\x44\x65leteNamedWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\"-\n\x1b\x44\x65leteNamedWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"d\n\x13\x44\x65leteScriptRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x13\n\x0bscript_name\x18\x03 \x01(\t\"&\n\x14\x44\x65leteScriptResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x0e\x44isableRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"!\n\x0f\x44isableResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"V\n\x1a\x44isableAnalogFilterRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"-\n\x1b\x44isableAnalogFilterResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"W\n\x1b\x44isableDigitalFilterRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\".\n\x1c\x44isableDigitalFilterResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"[\n\x1f\x44isableDigitalPatterningRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"2\n DisableDigitalPatterningResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"U\n\x1b\x44isableScriptTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\ntrigger_id\x18\x02 \x01(\t\".\n\x1c\x44isableScriptTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"@\n\x1a\x44isableStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"-\n\x1b\x44isableStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"z\n\x19\x45nableAnalogFilterRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12#\n\x1b\x66ilter_correction_frequency\x18\x03 \x01(\x01\",\n\x1a\x45nableAnalogFilterResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"V\n\x1a\x45nableDigitalFilterRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"-\n\x1b\x45nableDigitalFilterResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"Z\n\x1e\x45nableDigitalPatterningRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"1\n\x1f\x45nableDigitalPatterningResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"M\n\x13\x45rrorHandlerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nerror_code\x18\x02 \x01(\x11\"=\n\x14\x45rrorHandlerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"M\n\x13\x45rrorMessageRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nerror_code\x18\x02 \x01(\x11\"=\n\x14\x45rrorMessageResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"7\n\x11\x45rrorQueryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"O\n\x12\x45rrorQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nerror_code\x18\x02 \x01(\x11\x12\x15\n\rerror_message\x18\x03 \x01(\t\"O\n)ExportAttributeConfigurationBufferRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"S\n*ExportAttributeConfigurationBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rconfiguration\x18\x02 \x01(\x0c\"`\n\'ExportAttributeConfigurationFileRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\":\n(ExportAttributeConfigurationFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb9\x01\n\x13\x45xportSignalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12%\n\x06signal\x18\x02 \x01(\x0e\x32\x13.nifgen_grpc.SignalH\x00\x12\x14\n\nsignal_raw\x18\x03 \x01(\x11H\x00\x12\x19\n\x11signal_identifier\x18\x04 \x01(\t\x12\x17\n\x0foutput_terminal\x18\x05 \x01(\tB\r\n\x0bsignal_enum\"&\n\x14\x45xportSignalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8c\x01\n\x1cGetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"H\n\x1dGetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x08\"\x8a\x01\n\x1aGetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"F\n\x1bGetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x11\"\x8a\x01\n\x1aGetAttributeViInt64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"F\n\x1bGetAttributeViInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x03\"\x8b\x01\n\x1bGetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"G\n\x1cGetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x01\"\x8c\x01\n\x1cGetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"`\n\x1dGetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12/\n\x0f\x61ttribute_value\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x8b\x01\n\x1bGetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"G\n\x1cGetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\t\"J\n\x15GetChannelNameRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\x11\"@\n\x16GetChannelNameResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x16\n\x0e\x63hannel_string\x18\x02 \x01(\t\"5\n\x0fGetErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"Q\n\x10GetErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nerror_code\x18\x02 \x01(\x11\x12\x19\n\x11\x65rror_description\x18\x03 \x01(\t\"E\n\x1fGetExtCalLastDateAndTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"z\n GetExtCalLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\x11\x12\r\n\x05month\x18\x03 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\x11\x12\x0c\n\x04hour\x18\x05 \x01(\x11\x12\x0e\n\x06minute\x18\x06 \x01(\x11\">\n\x18GetExtCalLastTempRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"@\n\x19GetExtCalLastTempResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"I\n#GetExtCalRecommendedIntervalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"F\n$GetExtCalRecommendedIntervalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0e\n\x06months\x18\x02 \x01(\x11\"[\n\x1fGetFIRFilterCoefficientsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"s\n GetFIRFilterCoefficientsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1a\n\x12\x63oefficients_array\x18\x02 \x03(\x01\x12#\n\x1bnumber_of_coefficients_read\x18\x03 \x01(\x11\"=\n\x17GetHardwareStateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"h\n\x18GetHardwareStateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12)\n\x05state\x18\x02 \x01(\x0e\x32\x1a.nifgen_grpc.HardwareState\x12\x11\n\tstate_raw\x18\x03 \x01(\x11\"B\n\x1cGetNextCoercionRecordRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"H\n\x1dGetNextCoercionRecordResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x63oercion_record\x18\x02 \x01(\t\"F\n GetNextInterchangeWarningRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"P\n!GetNextInterchangeWarningResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1b\n\x13interchange_warning\x18\x02 \x01(\t\"F\n GetSelfCalLastDateAndTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"{\n!GetSelfCalLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\x11\x12\r\n\x05month\x18\x03 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\x11\x12\x0c\n\x04hour\x18\x05 \x01(\x11\x12\x0e\n\x06minute\x18\x06 \x01(\x11\"?\n\x19GetSelfCalLastTempRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"A\n\x1aGetSelfCalLastTempResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"@\n\x1aGetSelfCalSupportedRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"I\n\x1bGetSelfCalSupportedResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1a\n\x12self_cal_supported\x18\x02 \x01(\x08\"]\n\x1eGetStreamEndpointHandleRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0fstream_endpoint\x18\x02 \x01(\t\"H\n\x1fGetStreamEndpointHandleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rreader_handle\x18\x02 \x01(\r\"f\n)ImportAttributeConfigurationBufferRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rconfiguration\x18\x02 \x01(\x0c\"<\n*ImportAttributeConfigurationBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"`\n\'ImportAttributeConfigurationFileRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\":\n(ImportAttributeConfigurationFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb1\x01\n\x0bInitRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x10\n\x08id_query\x18\x03 \x01(\x08\x12\x14\n\x0creset_device\x18\x04 \x01(\x08\x12M\n\x17initialization_behavior\x18\x05 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"~\n\x0cInitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"\xd3\x01\n\x16InitWithOptionsRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x10\n\x08id_query\x18\x03 \x01(\x08\x12\x14\n\x0creset_device\x18\x04 \x01(\x08\x12\x15\n\roption_string\x18\x05 \x01(\t\x12M\n\x17initialization_behavior\x18\x06 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"\x89\x01\n\x17InitWithOptionsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"\xde\x01\n\x1dInitializeWithChannelsRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x14\n\x0c\x63hannel_name\x18\x03 \x01(\t\x12\x14\n\x0creset_device\x18\x04 \x01(\x08\x12\x15\n\roption_string\x18\x05 \x01(\t\x12M\n\x17initialization_behavior\x18\x06 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"\x90\x01\n\x1eInitializeWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"?\n\x19InitiateGenerationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\",\n\x1aInitiateGenerationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"D\n\x1eInvalidateAllAttributesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"1\n\x1fInvalidateAllAttributesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"3\n\rIsDoneRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\".\n\x0eIsDoneResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04\x64one\x18\x02 \x01(\x08\"Y\n\x1cManualEnableP2PStreamRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rendpoint_name\x18\x02 \x01(\t\"/\n\x1dManualEnableP2PStreamResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"D\n\x1eQueryArbSeqCapabilitiesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\xb4\x01\n\x1fQueryArbSeqCapabilitiesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12#\n\x1bmaximum_number_of_sequences\x18\x02 \x01(\x11\x12\x1f\n\x17minimum_sequence_length\x18\x03 \x01(\x11\x12\x1f\n\x17maximum_sequence_length\x18\x04 \x01(\x11\x12\x1a\n\x12maximum_loop_count\x18\x05 \x01(\x11\"D\n\x1eQueryArbWfmCapabilitiesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\xae\x01\n\x1fQueryArbWfmCapabilitiesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12#\n\x1bmaximum_number_of_waveforms\x18\x02 \x01(\x11\x12\x18\n\x10waveform_quantum\x18\x03 \x01(\x11\x12\x1d\n\x15minimum_waveform_size\x18\x04 \x01(\x11\x12\x1d\n\x15maximum_waveform_size\x18\x05 \x01(\x11\"F\n QueryFreqListCapabilitiesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\xa2\x02\n!QueryFreqListCapabilitiesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12$\n\x1cmaximum_number_of_freq_lists\x18\x02 \x01(\x11\x12%\n\x1dminimum_frequency_list_length\x18\x03 \x01(\x11\x12%\n\x1dmaximum_frequency_list_length\x18\x04 \x01(\x11\x12\'\n\x1fminimum_frequency_list_duration\x18\x05 \x01(\x01\x12\'\n\x1fmaximum_frequency_list_duration\x18\x06 \x01(\x01\x12\'\n\x1f\x66requency_list_duration_quantum\x18\x07 \x01(\x01\"C\n\x1dReadCurrentTemperatureRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"E\n\x1eReadCurrentTemperatureResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"2\n\x0cResetRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rResetResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x85\x01\n\x15ResetAttributeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"(\n\x16ResetAttributeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"8\n\x12ResetDeviceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"%\n\x13ResetDeviceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"B\n\x1cResetInterchangeCheckRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dResetInterchangeCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\">\n\x18ResetWithDefaultsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"+\n\x19ResetWithDefaultsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\":\n\x14RevisionQueryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"f\n\x15RevisionQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x1ainstrument_driver_revision\x18\x02 \x01(\t\x12\x19\n\x11\x66irmware_revision\x18\x03 \x01(\t\"\xb5\x02\n\x15RouteSignalOutRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x39\n\x11route_signal_from\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.RouteSignalFromH\x00\x12\x1f\n\x15route_signal_from_raw\x18\x04 \x01(\x11H\x00\x12\x35\n\x0froute_signal_to\x18\x05 \x01(\x0e\x32\x1a.nifgen_grpc.RouteSignalToH\x01\x12\x1d\n\x13route_signal_to_raw\x18\x06 \x01(\x11H\x01\x42\x18\n\x16route_signal_from_enumB\x16\n\x14route_signal_to_enum\"(\n\x16RouteSignalOutResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x0eSelfCalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"!\n\x0fSelfCalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"5\n\x0fSelfTestRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"W\n\x10SelfTestResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x18\n\x10self_test_result\x18\x02 \x01(\x11\x12\x19\n\x11self_test_message\x18\x03 \x01(\t\"\xa8\x01\n\x1eSendSoftwareEdgeTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\'\n\x07trigger\x18\x02 \x01(\x0e\x32\x14.nifgen_grpc.TriggerH\x00\x12\x15\n\x0btrigger_raw\x18\x03 \x01(\x11H\x00\x12\x12\n\ntrigger_id\x18\x04 \x01(\tB\x0e\n\x0ctrigger_enum\"1\n\x1fSendSoftwareEdgeTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa5\x01\n\x1cSetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x17\n\x0f\x61ttribute_value\x18\x04 \x01(\x08\"/\n\x1dSetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x85\x02\n\x1aSetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x42\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32\'.nifgen_grpc.NiFgenInt32AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x11H\x00\x42\x16\n\x14\x61ttribute_value_enum\"-\n\x1bSetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa7\x01\n\x1aSetAttributeViInt64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\x03\"-\n\x1bSetAttributeViInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x87\x02\n\x1bSetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x43\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32(.nifgen_grpc.NiFgenReal64AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x01H\x00\x42\x16\n\x14\x61ttribute_value_enum\".\n\x1cSetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbd\x01\n\x1cSetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12/\n\x0f\x61ttribute_value\x18\x04 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dSetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x94\x02\n\x1bSetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x1d\n\x13\x61ttribute_value_raw\x18\x04 \x01(\tH\x00\x12P\n\x16\x61ttribute_value_mapped\x18\x05 \x01(\x0e\x32..nifgen_grpc.NiFgenStringAttributeValuesMappedH\x00\x42\x16\n\x14\x61ttribute_value_enum\".\n\x1cSetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xea\x01\n(SetNamedWaveformNextWritePositionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12.\n\x0brelative_to\x18\x04 \x01(\x0e\x32\x17.nifgen_grpc.RelativeToH\x00\x12\x19\n\x0frelative_to_raw\x18\x05 \x01(\x11H\x00\x12\x0e\n\x06offset\x18\x06 \x01(\x11\x42\x12\n\x10relative_to_enum\";\n)SetNamedWaveformNextWritePositionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe7\x01\n#SetWaveformNextWritePositionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fwaveform_handle\x18\x03 \x01(\x11\x12.\n\x0brelative_to\x18\x04 \x01(\x0e\x32\x17.nifgen_grpc.RelativeToH\x00\x12\x19\n\x0frelative_to_raw\x18\x05 \x01(\x11H\x00\x12\x0e\n\x06offset\x18\x06 \x01(\x11\x42\x12\n\x10relative_to_enum\"6\n$SetWaveformNextWritePositionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"L\n\x14WaitUntilDoneRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x10\n\x08max_time\x18\x02 \x01(\x11\"\'\n\x15WaitUntilDoneResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x7f\n\x1cWriteBinary16WaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fwaveform_handle\x18\x03 \x01(\x11\x12\x0c\n\x04\x64\x61ta\x18\x04 \x03(\x11\"/\n\x1dWriteBinary16WaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa3\x01\n#WriteComplexBinary16WaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fwaveform_handle\x18\x03 \x01(\x11\x12)\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x1b.nidevice_grpc.NIComplexI16\"6\n$WriteComplexBinary16WaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa4\x01\n#WriteNamedWaveformComplexF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12,\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\"6\n$WriteNamedWaveformComplexF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa1\x01\n#WriteNamedWaveformComplexI16Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12)\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x1b.nidevice_grpc.NIComplexI16\"6\n$WriteNamedWaveformComplexI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"}\n\x1cWriteNamedWaveformF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x03(\x01\"/\n\x1dWriteNamedWaveformF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"}\n\x1cWriteNamedWaveformI16Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x03(\x11\"/\n\x1dWriteNamedWaveformI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"n\n\x1aWriteP2PEndpointI16Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rendpoint_name\x18\x02 \x01(\t\x12\x15\n\rendpoint_data\x18\x03 \x03(\x11\"-\n\x1bWriteP2PEndpointI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"^\n\x12WriteScriptRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0e\n\x06script\x18\x03 \x01(\t\"%\n\x13WriteScriptResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"w\n\x14WriteWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fwaveform_handle\x18\x03 \x01(\x11\x12\x0c\n\x04\x64\x61ta\x18\x04 \x03(\x01\"\'\n\x15WriteWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa1\x01\n\x1eWriteWaveformComplexF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12,\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\x12\x17\n\x0fwaveform_handle\x18\x04 \x01(\x11\"1\n\x1fWriteWaveformComplexF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05*\xa9S\n\x0fNiFgenAttribute\x12 \n\x1cNIFGEN_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\"\n\x1cNIFGEN_ATTRIBUTE_RANGE_CHECK\x10\x92\x8b@\x12.\n(NIFGEN_ATTRIBUTE_QUERY_INSTRUMENT_STATUS\x10\x93\x8b@\x12\x1c\n\x16NIFGEN_ATTRIBUTE_CACHE\x10\x94\x8b@\x12\x1f\n\x19NIFGEN_ATTRIBUTE_SIMULATE\x10\x95\x8b@\x12\'\n!NIFGEN_ATTRIBUTE_RECORD_COERCIONS\x10\x96\x8b@\x12#\n\x1dNIFGEN_ATTRIBUTE_DRIVER_SETUP\x10\x97\x8b@\x12(\n\"NIFGEN_ATTRIBUTE_INTERCHANGE_CHECK\x10\xa5\x8b@\x12$\n\x1eNIFGEN_ATTRIBUTE_CHANNEL_COUNT\x10\xdb\x8c@\x12-\n\'NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_PREFIX\x10\xbe\x8d@\x12-\n\'NIFGEN_ATTRIBUTE_IO_RESOURCE_DESCRIPTOR\x10\xc0\x8d@\x12#\n\x1dNIFGEN_ATTRIBUTE_LOGICAL_NAME\x10\xc1\x8d@\x12\x32\n,NIFGEN_ATTRIBUTE_SUPPORTED_INSTRUMENT_MODELS\x10\xd7\x8d@\x12)\n#NIFGEN_ATTRIBUTE_GROUP_CAPABILITIES\x10\xa1\x8e@\x12\x34\n.NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_MAJOR_VERSION\x10\x87\x8f@\x12\x34\n.NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_MINOR_VERSION\x10\x88\x8f@\x12\x33\n-NIFGEN_ATTRIBUTE_INSTRUMENT_FIRMWARE_REVISION\x10\x8e\x8f@\x12.\n(NIFGEN_ATTRIBUTE_INSTRUMENT_MANUFACTURER\x10\x8f\x8f@\x12\'\n!NIFGEN_ATTRIBUTE_INSTRUMENT_MODEL\x10\x90\x8f@\x12-\n\'NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_VENDOR\x10\x91\x8f@\x12\x32\n,NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_DESCRIPTION\x10\x92\x8f@\x12?\n9NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION\x10\x93\x8f@\x12?\n9NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION\x10\x94\x8f@\x12/\n)NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_REVISION\x10\xb7\x8f@\x12(\n\"NIFGEN_ATTRIBUTE_ID_QUERY_RESPONSE\x10\xb1\x98\x46\x12.\n(NIFGEN_ATTRIBUTE_DIGITAL_PATTERN_ENABLED\x10\x95\x99\x46\x12-\n\'NIFGEN_ATTRIBUTE_DIGITAL_FILTER_ENABLED\x10\x96\x99\x46\x12,\n&NIFGEN_ATTRIBUTE_ANALOG_FILTER_ENABLED\x10\x97\x99\x46\x12\x32\n,NIFGEN_ATTRIBUTE_FILTER_CORRECTION_FREQUENCY\x10\x98\x99\x46\x12+\n%NIFGEN_ATTRIBUTE_SYNC_DUTY_CYCLE_HIGH\x10\x99\x99\x46\x12*\n$NIFGEN_ATTRIBUTE_UPDATE_CLOCK_SOURCE\x10\x9a\x99\x46\x12*\n$NIFGEN_ATTRIBUTE_REF_CLOCK_FREQUENCY\x10\x9b\x99\x46\x12#\n\x1dNIFGEN_ATTRIBUTE_TRIGGER_MODE\x10\x9c\x99\x46\x12!\n\x1bNIFGEN_ATTRIBUTE_CLOCK_MODE\x10\x9e\x99\x46\x12&\n NIFGEN_ATTRIBUTE_SYNCHRONIZATION\x10\x9f\x99\x46\x12*\n$NIFGEN_ATTRIBUTE_SAMPLE_CLOCK_SOURCE\x10\xa0\x99\x46\x12-\n\'NIFGEN_ATTRIBUTE_REFERENCE_CLOCK_SOURCE\x10\xa1\x99\x46\x12\'\n!NIFGEN_ATTRIBUTE_FREQ_LIST_HANDLE\x10\x80\x9a\x46\x12)\n#NIFGEN_ATTRIBUTE_MAX_NUM_FREQ_LISTS\x10\x81\x9a\x46\x12+\n%NIFGEN_ATTRIBUTE_MIN_FREQ_LIST_LENGTH\x10\x82\x9a\x46\x12+\n%NIFGEN_ATTRIBUTE_MAX_FREQ_LIST_LENGTH\x10\x83\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_MIN_FREQ_LIST_DURATION\x10\x84\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_MAX_FREQ_LIST_DURATION\x10\x85\x9a\x46\x12\x31\n+NIFGEN_ATTRIBUTE_FREQ_LIST_DURATION_QUANTUM\x10\x86\x9a\x46\x12\x1f\n\x19NIFGEN_ATTRIBUTE_BUS_TYPE\x10\x87\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_VIDEO_WAVEFORM_TYPE\x10\x88\x9a\x46\x12:\n4NIFGEN_ATTRIBUTE_DIGITAL_FILTER_INTERPOLATION_FACTOR\x10\x8a\x9a\x46\x12\x34\n.NIFGEN_ATTRIBUTE_EXPORTED_SAMPLE_CLOCK_DIVISOR\x10\x8b\x9a\x46\x12%\n\x1fNIFGEN_ATTRIBUTE_LOAD_IMPEDANCE\x10\x8c\x9a\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_ANALOG_PATH\x10\x8e\x9a\x46\x12%\n\x1fNIFGEN_ATTRIBUTE_GAIN_DAC_VALUE\x10\x8f\x9a\x46\x12\'\n!NIFGEN_ATTRIBUTE_OFFSET_DAC_VALUE\x10\x90\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_OSCILLATOR_FREQ_DAC_VALUE\x10\x91\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_PRE_AMPLIFIER_ATTENUATION\x10\x94\x9a\x46\x12\x31\n+NIFGEN_ATTRIBUTE_POST_AMPLIFIER_ATTENUATION\x10\x95\x9a\x46\x12=\n7NIFGEN_ATTRIBUTE_EXPORTED_SAMPLE_CLOCK_TIMEBASE_DIVISOR\x10\x96\x9a\x46\x12\x32\n,NIFGEN_ATTRIBUTE_SAMPLE_CLOCK_ABSOLUTE_DELAY\x10\x97\x9a\x46\x12\x31\n+NIFGEN_ATTRIBUTE_OSCILLATOR_PHASE_DAC_VALUE\x10\x98\x9a\x46\x12\x38\n2NIFGEN_ATTRIBUTE_EXTERNAL_CLOCK_DELAY_BINARY_VALUE\x10\x99\x9a\x46\x12\'\n!NIFGEN_ATTRIBUTE_ANALOG_DATA_MASK\x10\x9a\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_ANALOG_STATIC_VALUE\x10\x9b\x9a\x46\x12(\n\"NIFGEN_ATTRIBUTE_DIGITAL_DATA_MASK\x10\x9c\x9a\x46\x12+\n%NIFGEN_ATTRIBUTE_DIGITAL_STATIC_VALUE\x10\x9d\x9a\x46\x12\'\n!NIFGEN_ATTRIBUTE_FUNC_BUFFER_SIZE\x10\x9e\x9a\x46\x12+\n%NIFGEN_ATTRIBUTE_FUNC_MAX_BUFFER_SIZE\x10\x9f\x9a\x46\x12/\n)NIFGEN_ATTRIBUTE_FILE_TRANSFER_BLOCK_SIZE\x10\xa0\x9a\x46\x12/\n)NIFGEN_ATTRIBUTE_DATA_TRANSFER_BLOCK_SIZE\x10\xa1\x9a\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_MEMORY_SIZE\x10\xa2\x9a\x46\x12$\n\x1eNIFGEN_ATTRIBUTE_SERIAL_NUMBER\x10\xa3\x9a\x46\x12)\n#NIFGEN_ATTRIBUTE_DIRECT_DMA_ENABLED\x10\xa4\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_DIRECT_DMA_WINDOW_SIZE\x10\xa5\x9a\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_OSP_ENABLED\x10\xa6\x9a\x46\x12/\n)NIFGEN_ATTRIBUTE_OSP_DATA_PROCESSING_MODE\x10\xa7\x9a\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_OSP_IQ_RATE\x10\xa8\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_CARRIER_ENABLED\x10\xa9\x9a\x46\x12,\n&NIFGEN_ATTRIBUTE_OSP_CARRIER_FREQUENCY\x10\xaa\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_CARRIER_PHASE_I\x10\xab\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_CARRIER_PHASE_Q\x10\xac\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_TYPE\x10\xad\x9a\x46\x12#\n\x1dNIFGEN_ATTRIBUTE_DIGITAL_GAIN\x10\xae\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_ENABLED\x10\xaf\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_INTERPOLATION\x10\xb0\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_OSP_CIC_FILTER_ENABLED\x10\xb1\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_OSP_CIC_FILTER_INTERPOLATION\x10\xb2\x9a\x46\x12>\n8NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_ROOT_RAISED_COSINE_ALPHA\x10\xb3\x9a\x46\x12\x39\n3NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_RAISED_COSINE_ALPHA\x10\xb4\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_FLAT_PASSBAND\x10\xb5\x9a\x46\x12\x31\n+NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_GAUSSIAN_BT\x10\xb6\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_CIC_FILTER_GAIN\x10\xb7\x9a\x46\x12,\n&NIFGEN_ATTRIBUTE_OSP_PRE_FILTER_GAIN_I\x10\xb8\x9a\x46\x12,\n&NIFGEN_ATTRIBUTE_OSP_PRE_FILTER_GAIN_Q\x10\xb9\x9a\x46\x12.\n(NIFGEN_ATTRIBUTE_OSP_PRE_FILTER_OFFSET_I\x10\xba\x9a\x46\x12.\n(NIFGEN_ATTRIBUTE_OSP_PRE_FILTER_OFFSET_Q\x10\xbb\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_OSP_OVERFLOW_ERROR_REPORTING\x10\xbc\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_OVERFLOW_STATUS\x10\xbd\x9a\x46\x12)\n#NIFGEN_ATTRIBUTE_SCRIPT_TO_GENERATE\x10\xbe\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_MARKER_EVENTS_COUNT\x10\xbf\x9a\x46\x12,\n&NIFGEN_ATTRIBUTE_SCRIPT_TRIGGERS_COUNT\x10\xc0\x9a\x46\x12/\n)NIFGEN_ATTRIBUTE_DATA_MARKER_EVENTS_COUNT\x10\xc1\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_DIRECT_DMA_WINDOW_ADDRESS\x10\xc2\x9a\x46\x12)\n#NIFGEN_ATTRIBUTE_START_TRIGGER_TYPE\x10\xc8\x9a\x46\x12\x38\n2NIFGEN_ATTRIBUTE_DIGITAL_EDGE_START_TRIGGER_SOURCE\x10\xc9\x9a\x46\x12\x36\n0NIFGEN_ATTRIBUTE_DIGITAL_EDGE_START_TRIGGER_EDGE\x10\xca\x9a\x46\x12=\n7NIFGEN_ATTRIBUTE_EXPORTED_START_TRIGGER_OUTPUT_TERMINAL\x10\xcb\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_SCRIPT_TRIGGER_TYPE\x10\xd2\x9a\x46\x12\x39\n3NIFGEN_ATTRIBUTE_DIGITAL_EDGE_SCRIPT_TRIGGER_SOURCE\x10\xd3\x9a\x46\x12\x37\n1NIFGEN_ATTRIBUTE_DIGITAL_EDGE_SCRIPT_TRIGGER_EDGE\x10\xd4\x9a\x46\x12:\n4NIFGEN_ATTRIBUTE_DIGITAL_LEVEL_SCRIPT_TRIGGER_SOURCE\x10\xd5\x9a\x46\x12@\n:NIFGEN_ATTRIBUTE_DIGITAL_LEVEL_SCRIPT_TRIGGER_ACTIVE_LEVEL\x10\xd6\x9a\x46\x12>\n8NIFGEN_ATTRIBUTE_EXPORTED_SCRIPT_TRIGGER_OUTPUT_TERMINAL\x10\xd7\x9a\x46\x12<\n6NIFGEN_ATTRIBUTE_READY_FOR_START_EVENT_OUTPUT_TERMINAL\x10\xe6\x9a\x46\x12?\n9NIFGEN_ATTRIBUTE_READY_FOR_START_EVENT_LEVEL_ACTIVE_LEVEL\x10\xe7\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_MARKER_EVENT_OUTPUT_TERMINAL\x10\xe8\x9a\x46\x12\x32\n,NIFGEN_ATTRIBUTE_MARKER_EVENT_PULSE_POLARITY\x10\xe9\x9a\x46\x12\x34\n.NIFGEN_ATTRIBUTE_STARTED_EVENT_OUTPUT_TERMINAL\x10\xea\x9a\x46\x12\x31\n+NIFGEN_ATTRIBUTE_DONE_EVENT_OUTPUT_TERMINAL\x10\xeb\x9a\x46\x12\x37\n1NIFGEN_ATTRIBUTE_STARTED_EVENT_LEVEL_ACTIVE_LEVEL\x10\xec\x9a\x46\x12\x34\n.NIFGEN_ATTRIBUTE_DONE_EVENT_LEVEL_ACTIVE_LEVEL\x10\xed\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_STARTED_EVENT_PULSE_POLARITY\x10\xee\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_DONE_EVENT_PULSE_POLARITY\x10\xef\x9a\x46\x12<\n6NIFGEN_ATTRIBUTE_EXPORTED_SAMPLE_CLOCK_OUTPUT_TERMINAL\x10\xf0\x9a\x46\x12?\n9NIFGEN_ATTRIBUTE_EXPORTED_REFERENCE_CLOCK_OUTPUT_TERMINAL\x10\xf1\x9a\x46\x12G\nANIFGEN_ATTRIBUTE_EXPORTED_ONBOARD_REFERENCE_CLOCK_OUTPUT_TERMINAL\x10\xf2\x9a\x46\x12\x32\n,NIFGEN_ATTRIBUTE_FLATNESS_CORRECTION_ENABLED\x10\xf3\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_STREAMING_WAVEFORM_HANDLE\x10\xf4\x9a\x46\x12<\n6NIFGEN_ATTRIBUTE_STREAMING_SPACE_AVAILABLE_IN_WAVEFORM\x10\xf5\x9a\x46\x12.\n(NIFGEN_ATTRIBUTE_STREAMING_WAVEFORM_NAME\x10\xf6\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_ARB_MARKER_POSITION\x10\xf7\x9a\x46\x12\'\n!NIFGEN_ATTRIBUTE_ARB_REPEAT_COUNT\x10\xf8\x9a\x46\x12\x45\n?NIFGEN_ATTRIBUTE_EXPORTED_SAMPLE_CLOCK_TIMEBASE_OUTPUT_TERMINAL\x10\xf9\x9a\x46\x12/\n)NIFGEN_ATTRIBUTE_SYNC_OUT_OUTPUT_TERMINAL\x10\xfa\x9a\x46\x12\x34\n.NIFGEN_ATTRIBUTE_STARTED_EVENT_OUTPUT_BEHAVIOR\x10\xfb\x9a\x46\x12\x31\n+NIFGEN_ATTRIBUTE_DONE_EVENT_OUTPUT_BEHAVIOR\x10\xfc\x9a\x46\x12\x36\n0NIFGEN_ATTRIBUTE_STARTED_EVENT_PULSE_WIDTH_UNITS\x10\xfd\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_DONE_EVENT_PULSE_WIDTH_UNITS\x10\xfe\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_STARTED_EVENT_PULSE_WIDTH\x10\xff\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_DONE_EVENT_PULSE_WIDTH\x10\x80\x9b\x46\x12\x38\n2NIFGEN_ATTRIBUTE_DATA_MARKER_EVENT_DATA_BIT_NUMBER\x10\x81\x9b\x46\x12\x37\n1NIFGEN_ATTRIBUTE_DATA_MARKER_EVENT_LEVEL_POLARITY\x10\x82\x9b\x46\x12\x38\n2NIFGEN_ATTRIBUTE_DATA_MARKER_EVENT_OUTPUT_TERMINAL\x10\x83\x9b\x46\x12/\n)NIFGEN_ATTRIBUTE_MARKER_EVENT_PULSE_WIDTH\x10\x84\x9b\x46\x12\x35\n/NIFGEN_ATTRIBUTE_MARKER_EVENT_PULSE_WIDTH_UNITS\x10\x85\x9b\x46\x12\x33\n-NIFGEN_ATTRIBUTE_MARKER_EVENT_OUTPUT_BEHAVIOR\x10\x86\x9b\x46\x12\x38\n2NIFGEN_ATTRIBUTE_MARKER_EVENT_TOGGLE_INITIAL_STATE\x10\x87\x9b\x46\x12\x34\n.NIFGEN_ATTRIBUTE_ALL_MARKER_EVENTS_LIVE_STATUS\x10\x88\x9b\x46\x12/\n)NIFGEN_ATTRIBUTE_MARKER_EVENT_LIVE_STATUS\x10\x89\x9b\x46\x12\x38\n2NIFGEN_ATTRIBUTE_READY_FOR_START_EVENT_LIVE_STATUS\x10\x8c\x9b\x46\x12\x37\n1NIFGEN_ATTRIBUTE_ALL_MARKER_EVENTS_LATCHED_STATUS\x10\x8d\x9b\x46\x12\x32\n,NIFGEN_ATTRIBUTE_MARKER_EVENT_LATCHED_STATUS\x10\x8e\x9b\x46\x12\x30\n*NIFGEN_ATTRIBUTE_DONE_EVENT_LATCHED_STATUS\x10\x8f\x9b\x46\x12\x33\n-NIFGEN_ATTRIBUTE_STARTED_EVENT_LATCHED_STATUS\x10\x90\x9b\x46\x12)\n#NIFGEN_ATTRIBUTE_MARKER_EVENT_DELAY\x10\x92\x9b\x46\x12/\n)NIFGEN_ATTRIBUTE_MARKER_EVENT_DELAY_UNITS\x10\x93\x9b\x46\x12*\n$NIFGEN_ATTRIBUTE_STARTED_EVENT_DELAY\x10\x94\x9b\x46\x12\x30\n*NIFGEN_ATTRIBUTE_STARTED_EVENT_DELAY_UNITS\x10\x95\x9b\x46\x12\'\n!NIFGEN_ATTRIBUTE_DONE_EVENT_DELAY\x10\x96\x9b\x46\x12-\n\'NIFGEN_ATTRIBUTE_DONE_EVENT_DELAY_UNITS\x10\x97\x9b\x46\x12\x34\n.NIFGEN_ATTRIBUTE_PCI_DMA_OPTIMIZATIONS_ENABLED\x10\x9a\x9b\x46\x12-\n\'NIFGEN_ATTRIBUTE_TERMINAL_CONFIGURATION\x10\x9d\x9b\x46\x12)\n#NIFGEN_ATTRIBUTE_COMMON_MODE_OFFSET\x10\x9e\x9b\x46\x12\x33\n-NIFGEN_ATTRIBUTE_SAMPLE_CLOCK_TIMEBASE_SOURCE\x10\x9f\x9b\x46\x12\x31\n+NIFGEN_ATTRIBUTE_SAMPLE_CLOCK_TIMEBASE_RATE\x10\xa0\x9b\x46\x12$\n\x1eNIFGEN_ATTRIBUTE_CHANNEL_DELAY\x10\xa1\x9b\x46\x12\x1f\n\x19NIFGEN_ATTRIBUTE_OSP_MODE\x10\xa2\x9b\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_FREQUENCY_SHIFT\x10\xa3\x9b\x46\x12\x36\n0NIFGEN_ATTRIBUTE_DATA_TRANSFER_MAXIMUM_BANDWIDTH\x10\xa5\x9b\x46\x12:\n4NIFGEN_ATTRIBUTE_DATA_TRANSFER_PREFERRED_PACKET_SIZE\x10\xa6\x9b\x46\x12<\n6NIFGEN_ATTRIBUTE_DATA_TRANSFER_MAXIMUM_IN_FLIGHT_READS\x10\xa7\x9b\x46\x12\x37\n1NIFGEN_ATTRIBUTE_EXTERNAL_SAMPLE_CLOCK_MULTIPLIER\x10\xa8\x9b\x46\x12$\n\x1eNIFGEN_ATTRIBUTE_IDLE_BEHAVIOR\x10\xa9\x9b\x46\x12!\n\x1bNIFGEN_ATTRIBUTE_IDLE_VALUE\x10\xaa\x9b\x46\x12$\n\x1eNIFGEN_ATTRIBUTE_WAIT_BEHAVIOR\x10\xab\x9b\x46\x12!\n\x1bNIFGEN_ATTRIBUTE_WAIT_VALUE\x10\xac\x9b\x46\x12<\n6NIFGEN_ATTRIBUTE_OSP_COMPENSATE_FOR_FILTER_GROUP_DELAY\x10\xb5\x9b\x46\x12&\n NIFGEN_ATTRIBUTE_MODULE_REVISION\x10\xb6\x9b\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_P2P_ENABLED\x10\xb7\x9b\x46\x12/\n)NIFGEN_ATTRIBUTE_P2P_DESTINATION_CHANNELS\x10\xb8\x9b\x46\x12(\n\"NIFGEN_ATTRIBUTE_P2P_ENDPOINT_SIZE\x10\xb9\x9b\x46\x12\x36\n0NIFGEN_ATTRIBUTE_P2P_SPACE_AVAILABLE_IN_ENDPOINT\x10\xba\x9b\x46\x12;\n5NIFGEN_ATTRIBUTE_P2P_MOST_SPACE_AVAILABLE_IN_ENDPOINT\x10\xbb\x9b\x46\x12)\n#NIFGEN_ATTRIBUTE_P2P_ENDPOINT_COUNT\x10\xbc\x9b\x46\x12\x37\n1NIFGEN_ATTRIBUTE_P2P_MANUAL_CONFIGURATION_ENABLED\x10\xbd\x9b\x46\x12;\n5NIFGEN_ATTRIBUTE_P2P_DATA_TRANSFER_PERMISSION_ADDRESS\x10\xbe\x9b\x46\x12@\n:NIFGEN_ATTRIBUTE_P2P_DATA_TRANSFER_PERMISSION_ADDRESS_TYPE\x10\xbf\x9b\x46\x12<\n6NIFGEN_ATTRIBUTE_P2P_DATA_TRANSFER_PERMISSION_INTERVAL\x10\xc0\x9b\x46\x12\x32\n,NIFGEN_ATTRIBUTE_P2P_ENDPOINT_WINDOW_ADDRESS\x10\xc1\x9b\x46\x12\x37\n1NIFGEN_ATTRIBUTE_P2P_ENDPOINT_WINDOW_ADDRESS_TYPE\x10\xc2\x9b\x46\x12/\n)NIFGEN_ATTRIBUTE_P2P_ENDPOINT_WINDOW_SIZE\x10\xc3\x9b\x46\x12\x34\n.NIFGEN_ATTRIBUTE_P2P_DONE_NOTIFICATION_ADDRESS\x10\xc5\x9b\x46\x12\x39\n3NIFGEN_ATTRIBUTE_P2P_DONE_NOTIFICATION_ADDRESS_TYPE\x10\xc6\x9b\x46\x12\x32\n,NIFGEN_ATTRIBUTE_P2P_DONE_NOTIFICATION_VALUE\x10\xc7\x9b\x46\x12\x43\n=NIFGEN_ATTRIBUTE_P2P_DATA_TRANSFER_PERMISSION_INITIAL_CREDITS\x10\xc8\x9b\x46\x12.\n(NIFGEN_ATTRIBUTE_STREAMING_WRITE_TIMEOUT\x10\xc9\x9b\x46\x12@\n:NIFGEN_ATTRIBUTE_P2P_ENDPOINT_FULLNESS_START_TRIGGER_LEVEL\x10\xca\x9b\x46\x12(\n\"NIFGEN_ATTRIBUTE_AUX_POWER_ENABLED\x10\xcb\x9b\x46\x12(\n\"NIFGEN_ATTRIBUTE_FPGA_BITFILE_PATH\x10\xcc\x9b\x46\x12%\n\x1fNIFGEN_ATTRIBUTE_ABSOLUTE_DELAY\x10\xcd\x9b\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_OUTPUT_MODE\x10\xd1\xa5L\x12%\n\x1fNIFGEN_ATTRIBUTE_OUTPUT_ENABLED\x10\xd3\xa5L\x12\'\n!NIFGEN_ATTRIBUTE_OUTPUT_IMPEDANCE\x10\xd4\xa5L\x12$\n\x1eNIFGEN_ATTRIBUTE_FUNC_WAVEFORM\x10\xb5\xa6L\x12%\n\x1fNIFGEN_ATTRIBUTE_FUNC_AMPLITUDE\x10\xb6\xa6L\x12%\n\x1fNIFGEN_ATTRIBUTE_FUNC_DC_OFFSET\x10\xb7\xa6L\x12%\n\x1fNIFGEN_ATTRIBUTE_FUNC_FREQUENCY\x10\xb8\xa6L\x12\'\n!NIFGEN_ATTRIBUTE_FUNC_START_PHASE\x10\xb9\xa6L\x12+\n%NIFGEN_ATTRIBUTE_FUNC_DUTY_CYCLE_HIGH\x10\xba\xa6L\x12*\n$NIFGEN_ATTRIBUTE_ARB_WAVEFORM_HANDLE\x10\x99\xa7L\x12\x1f\n\x19NIFGEN_ATTRIBUTE_ARB_GAIN\x10\x9a\xa7L\x12!\n\x1bNIFGEN_ATTRIBUTE_ARB_OFFSET\x10\x9b\xa7L\x12&\n NIFGEN_ATTRIBUTE_ARB_SAMPLE_RATE\x10\x9c\xa7L\x12(\n\"NIFGEN_ATTRIBUTE_MAX_NUM_WAVEFORMS\x10\x9d\xa7L\x12\'\n!NIFGEN_ATTRIBUTE_WAVEFORM_QUANTUM\x10\x9e\xa7L\x12(\n\"NIFGEN_ATTRIBUTE_MIN_WAVEFORM_SIZE\x10\x9f\xa7L\x12(\n\"NIFGEN_ATTRIBUTE_MAX_WAVEFORM_SIZE\x10\xa0\xa7L\x12*\n$NIFGEN_ATTRIBUTE_ARB_SEQUENCE_HANDLE\x10\xa3\xa7L\x12(\n\"NIFGEN_ATTRIBUTE_MAX_NUM_SEQUENCES\x10\xa4\xa7L\x12*\n$NIFGEN_ATTRIBUTE_MIN_SEQUENCE_LENGTH\x10\xa5\xa7L\x12*\n$NIFGEN_ATTRIBUTE_MAX_SEQUENCE_LENGTH\x10\xa6\xa7L\x12%\n\x1fNIFGEN_ATTRIBUTE_MAX_LOOP_COUNT\x10\xa7\xa7L\x12%\n\x1fNIFGEN_ATTRIBUTE_TRIGGER_SOURCE\x10\xfe\xa7L\x12\"\n\x1cNIFGEN_ATTRIBUTE_BURST_COUNT\x10\xae\xa8L*Z\n\tByteOrder\x12\'\n#BYTE_ORDER_NIFGEN_VAL_LITTLE_ENDIAN\x10\x00\x12$\n BYTE_ORDER_NIFGEN_VAL_BIG_ENDIAN\x10\x01*\x82\x01\n\tClockMode\x12)\n%CLOCK_MODE_NIFGEN_VAL_HIGH_RESOLUTION\x10\x00\x12%\n!CLOCK_MODE_NIFGEN_VAL_DIVIDE_DOWN\x10\x01\x12#\n\x1f\x43LOCK_MODE_NIFGEN_VAL_AUTOMATIC\x10\x02*y\n\x14\x46requencyListOptions\x12&\n\"FREQUENCY_LIST_OPTIONS_UNSPECIFIED\x10\x00\x12\x39\n,FREQUENCY_LIST_OPTIONS_NIFGEN_VAL_ALL_FLISTS\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01*\xe8\x01\n\rHardwareState\x12\"\n\x1eHARDWARE_STATE_NIFGEN_VAL_IDLE\x10\x00\x12\x37\n3HARDWARE_STATE_NIFGEN_VAL_WAITING_FOR_START_TRIGGER\x10\x64\x12&\n!HARDWARE_STATE_NIFGEN_VAL_RUNNING\x10\xc8\x01\x12#\n\x1eHARDWARE_STATE_NIFGEN_VAL_DONE\x10\xd8\x04\x12-\n(HARDWARE_STATE_NIFGEN_VAL_HARDWARE_ERROR\x10\xe8\x07*\xc1Q\n\x1aNiFgenInt32AttributeValues\x12\x1c\n\x18NIFGEN_INT32_UNSPECIFIED\x10\x00\x12/\n+NIFGEN_INT32_ADDRESS_TYPE_VAL_ADDR_PHYSICAL\x10\x00\x12.\n*NIFGEN_INT32_ADDRESS_TYPE_VAL_ADDR_VIRTUAL\x10\x01\x12\x31\n-NIFGEN_INT32_ANALOG_PATH_VAL_MAIN_ANALOG_PATH\x10\x00\x12\x33\n/NIFGEN_INT32_ANALOG_PATH_VAL_DIRECT_ANALOG_PATH\x10\x01\x12;\n7NIFGEN_INT32_ANALOG_PATH_VAL_FIXED_LOW_GAIN_ANALOG_PATH\x10\x02\x12<\n8NIFGEN_INT32_ANALOG_PATH_VAL_FIXED_HIGH_GAIN_ANALOG_PATH\x10\x03\x12\x46\n@NIFGEN_INT32_ARBITRARY_SEQUENCE_HANDLE_VAL_FIRST_SEQUENCE_HANDLE\x10\xa0\x8d\x06\x12\x45\n?NIFGEN_INT32_ARBITRARY_SEQUENCE_HANDLE_VAL_LAST_SEQUENCE_HANDLE\x10\xaf\xdb\x06\x12\x43\n6NIFGEN_INT32_ARBITRARY_SEQUENCE_HANDLE_VAL_NO_SEQUENCE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x45\n@NIFGEN_INT32_ARBITRARY_WAVEFORM_HANDLE_VAL_FIRST_WAVEFORM_HANDLE\x10\x90N\x12\x44\n?NIFGEN_INT32_ARBITRARY_WAVEFORM_HANDLE_VAL_LAST_WAVEFORM_HANDLE\x10\xf7U\x12\x43\n6NIFGEN_INT32_ARBITRARY_WAVEFORM_HANDLE_VAL_NO_WAVEFORM\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0NIFGEN_INT32_BURST_COUNT_VAL_GENERATE_CONTINUOUS\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12)\n%NIFGEN_INT32_BUS_TYPE_VAL_BUS_INVALID\x10\x00\x12$\n NIFGEN_INT32_BUS_TYPE_VAL_BUS_AT\x10\x01\x12%\n!NIFGEN_INT32_BUS_TYPE_VAL_BUS_PCI\x10\x02\x12%\n!NIFGEN_INT32_BUS_TYPE_VAL_BUS_PXI\x10\x03\x12%\n!NIFGEN_INT32_BUS_TYPE_VAL_BUS_VXI\x10\x04\x12(\n$NIFGEN_INT32_BUS_TYPE_VAL_BUS_PCMCIA\x10\x05\x12&\n\"NIFGEN_INT32_BUS_TYPE_VAL_BUS_PXIE\x10\x06\x12/\n+NIFGEN_INT32_CLOCK_MODE_VAL_HIGH_RESOLUTION\x10\x00\x12+\n\'NIFGEN_INT32_CLOCK_MODE_VAL_DIVIDE_DOWN\x10\x01\x12)\n%NIFGEN_INT32_CLOCK_MODE_VAL_AUTOMATIC\x10\x02\x12\x41\n=NIFGEN_INT32_DATA_MARKER_EVENT_LEVEL_POLARITY_VAL_ACTIVE_HIGH\x10\x65\x12@\n<NIFGEN_INT32_DATA_MARKER_EVENT_LEVEL_POLARITY_VAL_ACTIVE_LOW\x10\x66\x12\x32\n.NIFGEN_INT32_DATA_PROCESSING_MODE_VAL_OSP_REAL\x10\x00\x12\x35\n1NIFGEN_INT32_DATA_PROCESSING_MODE_VAL_OSP_COMPLEX\x10\x01\x12\x38\n4NIFGEN_INT32_DONE_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_HIGH\x10\x65\x12\x37\n3NIFGEN_INT32_DONE_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_LOW\x10\x66\x12@\n<NIFGEN_INT32_DONE_EVENT_DELAY_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12\x33\n/NIFGEN_INT32_DONE_EVENT_DELAY_UNITS_VAL_SECONDS\x10\x66\x12\x35\n1NIFGEN_INT32_DONE_EVENT_OUTPUT_BEHAVIOR_VAL_PULSE\x10\x65\x12\x35\n1NIFGEN_INT32_DONE_EVENT_OUTPUT_BEHAVIOR_VAL_LEVEL\x10\x66\x12:\n6NIFGEN_INT32_DONE_EVENT_PULSE_POLARITY_VAL_ACTIVE_HIGH\x10\x65\x12\x39\n5NIFGEN_INT32_DONE_EVENT_PULSE_POLARITY_VAL_ACTIVE_LOW\x10\x66\x12\x46\nBNIFGEN_INT32_DONE_EVENT_PULSE_WIDTH_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12\x39\n5NIFGEN_INT32_DONE_EVENT_PULSE_WIDTH_UNITS_VAL_SECONDS\x10\x66\x12)\n%NIFGEN_INT32_FILTER_TYPE_VAL_OSP_FLAT\x10\x00\x12\x32\n.NIFGEN_INT32_FILTER_TYPE_VAL_OSP_RAISED_COSINE\x10\x01\x12\x37\n3NIFGEN_INT32_FILTER_TYPE_VAL_OSP_ROOT_RAISED_COSINE\x10\x02\x12-\n)NIFGEN_INT32_FILTER_TYPE_VAL_OSP_GAUSSIAN\x10\x03\x12+\n\'NIFGEN_INT32_FILTER_TYPE_VAL_OSP_CUSTOM\x10\x04\x12\x43\n=NIFGEN_INT32_FREQUENCY_LIST_HANDLE_VAL_FIRST_FREQ_LIST_HANDLE\x10\xc0\x9a\x0c\x12\x42\n<NIFGEN_INT32_FREQUENCY_LIST_HANDLE_VAL_LAST_FREQ_LIST_HANDLE\x10\xcf\xe8\x0c\x12@\n3NIFGEN_INT32_FREQUENCY_LIST_HANDLE_VAL_NO_FREQ_LIST\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n.NIFGEN_INT32_IDLE_BEHAVIOR_VAL_HOLD_LAST_VALUE\x10\x90\x03\x12\x31\n,NIFGEN_INT32_IDLE_BEHAVIOR_VAL_JUMP_TO_VALUE\x10\x91\x03\x12\x42\n>NIFGEN_INT32_MARKER_EVENT_DELAY_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12\x35\n1NIFGEN_INT32_MARKER_EVENT_DELAY_UNITS_VAL_SECONDS\x10\x66\x12\x37\n3NIFGEN_INT32_MARKER_EVENT_OUTPUT_BEHAVIOR_VAL_PULSE\x10\x65\x12\x37\n3NIFGEN_INT32_MARKER_EVENT_OUTPUT_BEHAVIOR_VAL_LEVEL\x10\x66\x12\x38\n4NIFGEN_INT32_MARKER_EVENT_OUTPUT_BEHAVIOR_VAL_TOGGLE\x10g\x12<\n8NIFGEN_INT32_MARKER_EVENT_PULSE_POLARITY_VAL_ACTIVE_HIGH\x10\x65\x12;\n7NIFGEN_INT32_MARKER_EVENT_PULSE_POLARITY_VAL_ACTIVE_LOW\x10\x66\x12H\nDNIFGEN_INT32_MARKER_EVENT_PULSE_WIDTH_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12;\n7NIFGEN_INT32_MARKER_EVENT_PULSE_WIDTH_UNITS_VAL_SECONDS\x10\x66\x12;\n7NIFGEN_INT32_MARKER_EVENT_TOGGLE_INITIAL_STATE_VAL_HIGH\x10\x65\x12:\n6NIFGEN_INT32_MARKER_EVENT_TOGGLE_INITIAL_STATE_VAL_LOW\x10\x66\x12$\n NIFGEN_INT32_OSP_MODE_VAL_OSP_IF\x10\x00\x12*\n&NIFGEN_INT32_OSP_MODE_VAL_OSP_BASEBAND\x10\x01\x12G\nCNIFGEN_INT32_OSP_OVERFLOW_ERROR_REPORTING_VAL_ERROR_REPORTING_ERROR\x10\x00\x12J\nFNIFGEN_INT32_OSP_OVERFLOW_ERROR_REPORTING_VAL_ERROR_REPORTING_DISABLED\x10\x02\x12:\n6NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_NONE\x10\x00\x12G\nCNIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PRE_FILTER_GAIN_I\x10\x01\x12G\nCNIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PRE_FILTER_GAIN_Q\x10\x02\x12I\nENIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PRE_FILTER_OFFSET_I\x10\x04\x12I\nENIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PRE_FILTER_OFFSET_Q\x10\x08\x12\x42\n>NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_FIR_FILTER_I\x10\x10\x12\x43\n?NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PFIR_FILTER_I\x10\x10\x12\x42\n>NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_FIR_FILTER_Q\x10 \x12\x43\n?NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PFIR_FILTER_Q\x10 \x12\x42\n>NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_CIC_FILTER_I\x10@\x12\x43\n>NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_CIC_FILTER_Q\x10\x80\x01\x12\x43\n>NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_COMPLEX_DATA\x10\x80\x02\x12\x44\n?NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_CFIR_FILTER_I\x10\x80\x04\x12\x44\n?NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_CFIR_FILTER_Q\x10\x80\x08\x12@\n;NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_EQUALIZER\x10\x80\x10\x12,\n(NIFGEN_INT32_OUTPUT_MODE_VAL_OUTPUT_FUNC\x10\x00\x12+\n\'NIFGEN_INT32_OUTPUT_MODE_VAL_OUTPUT_ARB\x10\x01\x12+\n\'NIFGEN_INT32_OUTPUT_MODE_VAL_OUTPUT_SEQ\x10\x02\x12\x31\n-NIFGEN_INT32_OUTPUT_MODE_VAL_OUTPUT_FREQ_LIST\x10\x65\x12.\n*NIFGEN_INT32_OUTPUT_MODE_VAL_OUTPUT_SCRIPT\x10\x66\x12\x43\n?NIFGEN_INT32_READY_FOR_START_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_HIGH\x10\x65\x12\x42\n>NIFGEN_INT32_READY_FOR_START_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_LOW\x10\x66\x12\x41\n=NIFGEN_INT32_SCRIPT_TRIGGER_DIGITAL_EDGE_EDGE_VAL_RISING_EDGE\x10\x65\x12\x42\n>NIFGEN_INT32_SCRIPT_TRIGGER_DIGITAL_EDGE_EDGE_VAL_FALLING_EDGE\x10\x66\x12J\nFNIFGEN_INT32_SCRIPT_TRIGGER_DIGITAL_LEVEL_ACTIVE_LEVEL_VAL_ACTIVE_HIGH\x10\x65\x12I\nENIFGEN_INT32_SCRIPT_TRIGGER_DIGITAL_LEVEL_ACTIVE_LEVEL_VAL_ACTIVE_LOW\x10\x66\x12\x32\n.NIFGEN_INT32_SCRIPT_TRIGGER_TYPE_VAL_TRIG_NONE\x10\x65\x12\x35\n1NIFGEN_INT32_SCRIPT_TRIGGER_TYPE_VAL_DIGITAL_EDGE\x10\x66\x12\x36\n2NIFGEN_INT32_SCRIPT_TRIGGER_TYPE_VAL_DIGITAL_LEVEL\x10g\x12\x36\n2NIFGEN_INT32_SCRIPT_TRIGGER_TYPE_VAL_SOFTWARE_EDGE\x10h\x12@\n<NIFGEN_INT32_START_TRIGGER_DIGITAL_EDGE_EDGE_VAL_RISING_EDGE\x10\x65\x12\x41\n=NIFGEN_INT32_START_TRIGGER_DIGITAL_EDGE_EDGE_VAL_FALLING_EDGE\x10\x66\x12\x31\n-NIFGEN_INT32_START_TRIGGER_TYPE_VAL_TRIG_NONE\x10\x65\x12\x34\n0NIFGEN_INT32_START_TRIGGER_TYPE_VAL_DIGITAL_EDGE\x10\x66\x12\x35\n1NIFGEN_INT32_START_TRIGGER_TYPE_VAL_SOFTWARE_EDGE\x10h\x12=\n9NIFGEN_INT32_START_TRIGGER_TYPE_VAL_P2P_ENDPOINT_FULLNESS\x10j\x12;\n7NIFGEN_INT32_STARTED_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_HIGH\x10\x65\x12:\n6NIFGEN_INT32_STARTED_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_LOW\x10\x66\x12\x43\n?NIFGEN_INT32_STARTED_EVENT_DELAY_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12\x36\n2NIFGEN_INT32_STARTED_EVENT_DELAY_UNITS_VAL_SECONDS\x10\x66\x12\x38\n4NIFGEN_INT32_STARTED_EVENT_OUTPUT_BEHAVIOR_VAL_PULSE\x10\x65\x12\x38\n4NIFGEN_INT32_STARTED_EVENT_OUTPUT_BEHAVIOR_VAL_LEVEL\x10\x66\x12=\n9NIFGEN_INT32_STARTED_EVENT_PULSE_POLARITY_VAL_ACTIVE_HIGH\x10\x65\x12<\n8NIFGEN_INT32_STARTED_EVENT_PULSE_POLARITY_VAL_ACTIVE_LOW\x10\x66\x12I\nENIFGEN_INT32_STARTED_EVENT_PULSE_WIDTH_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12<\n8NIFGEN_INT32_STARTED_EVENT_PULSE_WIDTH_UNITS_VAL_SECONDS\x10\x66\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL0\x10o\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL1\x10p\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL2\x10q\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL3\x10r\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL4\x10s\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL5\x10t\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL6\x10u\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_0\x10\x8d\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_1\x10\x8e\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_2\x10\x8f\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_3\x10\x90\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_4\x10\x91\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_5\x10\x92\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_6\x10\x93\x01\x12\x31\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_NONE\x10\xe8\x07\x12\x39\n4NIFGEN_INT32_TERMINAL_CONFIGURATION_VAL_SINGLE_ENDED\x10\xac\x02\x12\x39\n4NIFGEN_INT32_TERMINAL_CONFIGURATION_VAL_DIFFERENTIAL\x10\xad\x02\x12(\n$NIFGEN_INT32_TRIGGER_MODE_VAL_SINGLE\x10\x01\x12,\n(NIFGEN_INT32_TRIGGER_MODE_VAL_CONTINUOUS\x10\x02\x12)\n%NIFGEN_INT32_TRIGGER_MODE_VAL_STEPPED\x10\x03\x12\'\n#NIFGEN_INT32_TRIGGER_MODE_VAL_BURST\x10\x04\x12-\n)NIFGEN_INT32_TRIGGER_SOURCE_VAL_IMMEDIATE\x10\x00\x12,\n(NIFGEN_INT32_TRIGGER_SOURCE_VAL_EXTERNAL\x10\x01\x12\x31\n-NIFGEN_INT32_TRIGGER_SOURCE_VAL_SOFTWARE_TRIG\x10\x02\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL0\x10o\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL1\x10p\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL2\x10q\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL3\x10r\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL4\x10s\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL5\x10t\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL6\x10u\x12-\n(NIFGEN_INT32_TRIGGER_SOURCE_VAL_PXI_STAR\x10\x83\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_0\x10\x8d\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_1\x10\x8e\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_2\x10\x8f\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_3\x10\x90\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_4\x10\x91\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_5\x10\x92\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_6\x10\x93\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_7\x10\xf2\x07\x12*\n%NIFGEN_INT32_TRIGGER_SOURCE_VAL_PFI_0\x10\xf3\x07\x12*\n%NIFGEN_INT32_TRIGGER_SOURCE_VAL_PFI_1\x10\xf4\x07\x12*\n%NIFGEN_INT32_TRIGGER_SOURCE_VAL_PFI_2\x10\xf5\x07\x12*\n%NIFGEN_INT32_TRIGGER_SOURCE_VAL_PFI_3\x10\xf6\x07\x12\x33\n.NIFGEN_INT32_TRIGGER_SOURCE_VAL_OTHER_TERMINAL\x10\xfa\x07\x12\x31\n-NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_INTERNAL\x10\x00\x12\x31\n-NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_EXTERNAL\x10\x01\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL1\x10p\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL2\x10q\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL3\x10r\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL4\x10s\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL5\x10t\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL6\x10u\x12\x32\n-NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_PXI_STAR\x10\x83\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_0\x10\x8d\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_1\x10\x8e\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_2\x10\x8f\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_3\x10\x90\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_4\x10\x91\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_5\x10\x92\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_6\x10\x93\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_7\x10\xf2\x07\x12\x38\n3NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_OTHER_TERMINAL\x10\xfa\x07\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_CLK_IN\x10\xb2\t\x12\x34\n/NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_DDC_CLK_IN\x10\xb3\t\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_B\x10\x00\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_D\x10\x01\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_G\x10\x02\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_H\x10\x03\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_I\x10\x04\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_M\x10\x05\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_N\x10\x06\x12/\n+NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_NTSC_M\x10\x07\x12\x33\n.NIFGEN_INT32_WAIT_BEHAVIOR_VAL_HOLD_LAST_VALUE\x10\x90\x03\x12\x31\n,NIFGEN_INT32_WAIT_BEHAVIOR_VAL_JUMP_TO_VALUE\x10\x91\x03\x12&\n\"NIFGEN_INT32_WAVEFORM_VAL_WFM_SINE\x10\x01\x12(\n$NIFGEN_INT32_WAVEFORM_VAL_WFM_SQUARE\x10\x02\x12*\n&NIFGEN_INT32_WAVEFORM_VAL_WFM_TRIANGLE\x10\x03\x12)\n%NIFGEN_INT32_WAVEFORM_VAL_WFM_RAMP_UP\x10\x04\x12+\n\'NIFGEN_INT32_WAVEFORM_VAL_WFM_RAMP_DOWN\x10\x05\x12$\n NIFGEN_INT32_WAVEFORM_VAL_WFM_DC\x10\x06\x12\'\n#NIFGEN_INT32_WAVEFORM_VAL_WFM_NOISE\x10\x65\x12&\n\"NIFGEN_INT32_WAVEFORM_VAL_WFM_USER\x10\x66\x1a\x02\x10\x01*\xa7\x02\n\x1bNiFgenReal64AttributeValues\x12\x1d\n\x19NIFGEN_REAL64_UNSPECIFIED\x10\x00\x12\x44\n7NIFGEN_REAL64_LOAD_IMPEDANCE_VAL_MATCHED_LOAD_IMPEDANCE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n*NIFGEN_REAL64_OUTPUT_IMPEDANCE_VAL_50_OHMS\x10\x32\x12.\n*NIFGEN_REAL64_OUTPUT_IMPEDANCE_VAL_75_OHMS\x10K\x12?\n2NIFGEN_REAL64_SAMPLE_RATE_VAL_EXTERNAL_SAMPLE_RATE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x1a\x02\x10\x01*\xcf\n\n!NiFgenStringAttributeValuesMapped\x12$\n NIFGEN_STRING_MAPPED_UNSPECIFIED\x10\x00\x12I\nENIFGEN_STRING_REFERENCE_CLOCK_SOURCE_VAL_CLOCK_IN_COLLISION_AVOIDANCE\x10\x01\x12\x45\nANIFGEN_STRING_REFERENCE_CLOCK_SOURCE_VAL_NONE_COLLISION_AVOIDANCE\x10\x02\x12X\nTNIFGEN_STRING_REFERENCE_CLOCK_SOURCE_VAL_ONBOARD_REFERENCE_CLOCK_COLLISION_AVOIDANCE\x10\x03\x12J\nFNIFGEN_STRING_REFERENCE_CLOCK_SOURCE_VAL_PXI_CLOCK_COLLISION_AVOIDANCE\x10\x04\x12G\nCNIFGEN_STRING_REFERENCE_CLOCK_SOURCE_VAL_RTSI_7_COLLISION_AVOIDANCE\x10\x05\x12\x32\n.NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_CLOCK_IN\x10\x06\x12\x36\n2NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_DDC_CLOCK_IN\x10\x07\x12\x37\n3NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_ONBOARD_CLOCK\x10\x08\x12\x37\n3NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_STAR_LINE\x10\t\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_0_RTSI_0\x10\n\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_1_RTSI_1\x10\x0b\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_2_RTSI_2\x10\x0c\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_3_RTSI_3\x10\r\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_4_RTSI_4\x10\x0e\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_5_RTSI_5\x10\x0f\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_6_RTSI_6\x10\x10\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_7_RTSI_7\x10\x11\x12;\n7NIFGEN_STRING_SAMPLE_CLOCK_TIMEBASE_SOURCE_VAL_CLOCK_IN\x10\x12\x12@\n<NIFGEN_STRING_SAMPLE_CLOCK_TIMEBASE_SOURCE_VAL_ONBOARD_CLOCK\x10\x13*\xd9\x01\n\nOutputMode\x12&\n\"OUTPUT_MODE_NIFGEN_VAL_OUTPUT_FUNC\x10\x00\x12%\n!OUTPUT_MODE_NIFGEN_VAL_OUTPUT_ARB\x10\x01\x12%\n!OUTPUT_MODE_NIFGEN_VAL_OUTPUT_SEQ\x10\x02\x12+\n\'OUTPUT_MODE_NIFGEN_VAL_OUTPUT_FREQ_LIST\x10\x65\x12(\n$OUTPUT_MODE_NIFGEN_VAL_OUTPUT_SCRIPT\x10\x66*v\n\nRelativeTo\x12\x32\n.RELATIVE_TO_NIFGEN_VAL_WAVEFORM_POSITION_START\x10\x00\x12\x34\n0RELATIVE_TO_NIFGEN_VAL_WAVEFORM_POSITION_CURRENT\x10\x01*\x89\x07\n\x0fRouteSignalFrom\x12!\n\x1dROUTE_SIGNAL_FROM_UNSPECIFIED\x10\x00\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_MARKER\x10\xe9\x07\x12*\n%ROUTE_SIGNAL_FROM_NIFGEN_VAL_SYNC_OUT\x10\xea\x07\x12\x33\n.ROUTE_SIGNAL_FROM_NIFGEN_VAL_OUT_START_TRIGGER\x10\xec\x07\x12-\n(ROUTE_SIGNAL_FROM_NIFGEN_VAL_BOARD_CLOCK\x10\xee\x07\x12\x31\n,ROUTE_SIGNAL_FROM_NIFGEN_VAL_SYNCHRONIZATION\x10\xef\x07\x12.\n*ROUTE_SIGNAL_FROM_NIFGEN_VAL_SOFTWARE_TRIG\x10\x02\x12)\n$ROUTE_SIGNAL_FROM_NIFGEN_VAL_REF_OUT\x10\xf0\x07\x12+\n&ROUTE_SIGNAL_FROM_NIFGEN_VAL_CLOCK_OUT\x10\xf1\x07\x12*\n%ROUTE_SIGNAL_FROM_NIFGEN_VAL_PXI_STAR\x10\x83\x01\x12\'\n\"ROUTE_SIGNAL_FROM_NIFGEN_VAL_PFI_0\x10\xf3\x07\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_0\x10\x8d\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_1\x10\x8e\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_2\x10\x8f\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_3\x10\x90\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_4\x10\x91\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_5\x10\x92\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_6\x10\x93\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_7\x10\xf2\x07\x12\x39\n4ROUTE_SIGNAL_FROM_NIFGEN_VAL_ONBOARD_REFERENCE_CLOCK\x10\xfb\x07*\x91\x04\n\rRouteSignalTo\x12\x1f\n\x1bROUTE_SIGNAL_TO_UNSPECIFIED\x10\x00\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_0\x10\x8d\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_1\x10\x8e\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_2\x10\x8f\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_3\x10\x90\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_4\x10\x91\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_5\x10\x92\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_6\x10\x93\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_7\x10\xf2\x07\x12\'\n\"ROUTE_SIGNAL_TO_NIFGEN_VAL_REF_OUT\x10\xf0\x07\x12%\n ROUTE_SIGNAL_TO_NIFGEN_VAL_PFI_0\x10\xf3\x07\x12%\n ROUTE_SIGNAL_TO_NIFGEN_VAL_PFI_1\x10\xf4\x07\x12(\n#ROUTE_SIGNAL_TO_NIFGEN_VAL_PXI_STAR\x10\x83\x01*h\n\x0eSequenceHandle\x12\x1f\n\x1bSEQUENCE_HANDLE_UNSPECIFIED\x10\x00\x12\x35\n(SEQUENCE_HANDLE_NIFGEN_VAL_ALL_SEQUENCES\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01*\xa0\x04\n\x06Signal\x12\x16\n\x12SIGNAL_UNSPECIFIED\x10\x00\x12.\n)SIGNAL_NIFGEN_VAL_ONBOARD_REFERENCE_CLOCK\x10\xfb\x07\x12\x1f\n\x1aSIGNAL_NIFGEN_VAL_SYNC_OUT\x10\xea\x07\x12$\n\x1fSIGNAL_NIFGEN_VAL_START_TRIGGER\x10\xec\x07\x12#\n\x1eSIGNAL_NIFGEN_VAL_MARKER_EVENT\x10\xe9\x07\x12,\n\'SIGNAL_NIFGEN_VAL_SAMPLE_CLOCK_TIMEBASE\x10\xee\x07\x12&\n!SIGNAL_NIFGEN_VAL_SYNCHRONIZATION\x10\xef\x07\x12\"\n\x1eSIGNAL_NIFGEN_VAL_SAMPLE_CLOCK\x10\x65\x12%\n!SIGNAL_NIFGEN_VAL_REFERENCE_CLOCK\x10\x66\x12$\n SIGNAL_NIFGEN_VAL_SCRIPT_TRIGGER\x10g\x12+\n\'SIGNAL_NIFGEN_VAL_READY_FOR_START_EVENT\x10i\x12#\n\x1fSIGNAL_NIFGEN_VAL_STARTED_EVENT\x10j\x12 \n\x1cSIGNAL_NIFGEN_VAL_DONE_EVENT\x10k\x12\'\n#SIGNAL_NIFGEN_VAL_DATA_MARKER_EVENT\x10l*p\n\x07Trigger\x12\x17\n\x13TRIGGER_UNSPECIFIED\x10\x00\x12%\n TRIGGER_NIFGEN_VAL_START_TRIGGER\x10\xec\x07\x12%\n!TRIGGER_NIFGEN_VAL_SCRIPT_TRIGGER\x10g*\xbf\x01\n\x0bTriggerMode\x12\x1c\n\x18TRIGGER_MODE_UNSPECIFIED\x10\x00\x12\"\n\x1eTRIGGER_MODE_NIFGEN_VAL_SINGLE\x10\x01\x12&\n\"TRIGGER_MODE_NIFGEN_VAL_CONTINUOUS\x10\x02\x12#\n\x1fTRIGGER_MODE_NIFGEN_VAL_STEPPED\x10\x03\x12!\n\x1dTRIGGER_MODE_NIFGEN_VAL_BURST\x10\x04*|\n\x0bTriggerWhen\x12\x1c\n\x18TRIGGER_WHEN_UNSPECIFIED\x10\x00\x12\'\n#TRIGGER_WHEN_NIFGEN_VAL_ACTIVE_HIGH\x10\x65\x12&\n\"TRIGGER_WHEN_NIFGEN_VAL_ACTIVE_LOW\x10\x66*\xc1\x02\n\x08Waveform\x12\x18\n\x14WAVEFORM_UNSPECIFIED\x10\x00\x12 \n\x1cWAVEFORM_NIFGEN_VAL_WFM_SINE\x10\x01\x12\"\n\x1eWAVEFORM_NIFGEN_VAL_WFM_SQUARE\x10\x02\x12$\n WAVEFORM_NIFGEN_VAL_WFM_TRIANGLE\x10\x03\x12#\n\x1fWAVEFORM_NIFGEN_VAL_WFM_RAMP_UP\x10\x04\x12%\n!WAVEFORM_NIFGEN_VAL_WFM_RAMP_DOWN\x10\x05\x12\x1e\n\x1aWAVEFORM_NIFGEN_VAL_WFM_DC\x10\x06\x12!\n\x1dWAVEFORM_NIFGEN_VAL_WFM_NOISE\x10\x65\x12 \n\x1cWAVEFORM_NIFGEN_VAL_WFM_USER\x10\x66*h\n\x0eWaveformHandle\x12\x1f\n\x1bWAVEFORM_HANDLE_UNSPECIFIED\x10\x00\x12\x35\n(WAVEFORM_HANDLE_NIFGEN_VAL_ALL_WAVEFORMS\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x32\xc7p\n\x06NiFgen\x12\\\n\x0f\x41\x62ortGeneration\x12#.nifgen_grpc.AbortGenerationRequest\x1a$.nifgen_grpc.AbortGenerationResponse\x12\x89\x01\n\x1e\x41\x64justSampleClockRelativeDelay\x12\x32.nifgen_grpc.AdjustSampleClockRelativeDelayRequest\x1a\x33.nifgen_grpc.AdjustSampleClockRelativeDelayResponse\x12n\n\x15\x41llocateNamedWaveform\x12).nifgen_grpc.AllocateNamedWaveformRequest\x1a*.nifgen_grpc.AllocateNamedWaveformResponse\x12_\n\x10\x41llocateWaveform\x12$.nifgen_grpc.AllocateWaveformRequest\x1a%.nifgen_grpc.AllocateWaveformResponse\x12t\n\x17\x43heckAttributeViBoolean\x12+.nifgen_grpc.CheckAttributeViBooleanRequest\x1a,.nifgen_grpc.CheckAttributeViBooleanResponse\x12n\n\x15\x43heckAttributeViInt32\x12).nifgen_grpc.CheckAttributeViInt32Request\x1a*.nifgen_grpc.CheckAttributeViInt32Response\x12n\n\x15\x43heckAttributeViInt64\x12).nifgen_grpc.CheckAttributeViInt64Request\x1a*.nifgen_grpc.CheckAttributeViInt64Response\x12q\n\x16\x43heckAttributeViReal64\x12*.nifgen_grpc.CheckAttributeViReal64Request\x1a+.nifgen_grpc.CheckAttributeViReal64Response\x12t\n\x17\x43heckAttributeViSession\x12+.nifgen_grpc.CheckAttributeViSessionRequest\x1a,.nifgen_grpc.CheckAttributeViSessionResponse\x12q\n\x16\x43heckAttributeViString\x12*.nifgen_grpc.CheckAttributeViStringRequest\x1a+.nifgen_grpc.CheckAttributeViStringResponse\x12Y\n\x0e\x43learArbMemory\x12\".nifgen_grpc.ClearArbMemoryRequest\x1a#.nifgen_grpc.ClearArbMemoryResponse\x12_\n\x10\x43learArbSequence\x12$.nifgen_grpc.ClearArbSequenceRequest\x1a%.nifgen_grpc.ClearArbSequenceResponse\x12_\n\x10\x43learArbWaveform\x12$.nifgen_grpc.ClearArbWaveformRequest\x1a%.nifgen_grpc.ClearArbWaveformResponse\x12M\n\nClearError\x12\x1e.nifgen_grpc.ClearErrorRequest\x1a\x1f.nifgen_grpc.ClearErrorResponse\x12V\n\rClearFreqList\x12!.nifgen_grpc.ClearFreqListRequest\x1a\".nifgen_grpc.ClearFreqListResponse\x12w\n\x18\x43learInterchangeWarnings\x12,.nifgen_grpc.ClearInterchangeWarningsRequest\x1a-.nifgen_grpc.ClearInterchangeWarningsResponse\x12z\n\x19\x43learUserStandardWaveform\x12-.nifgen_grpc.ClearUserStandardWaveformRequest\x1a..nifgen_grpc.ClearUserStandardWaveformResponse\x12>\n\x05\x43lose\x12\x19.nifgen_grpc.CloseRequest\x1a\x1a.nifgen_grpc.CloseResponse\x12\x41\n\x06\x43ommit\x12\x1a.nifgen_grpc.CommitRequest\x1a\x1b.nifgen_grpc.CommitResponse\x12\x65\n\x12\x43onfigureAmplitude\x12&.nifgen_grpc.ConfigureAmplitudeRequest\x1a\'.nifgen_grpc.ConfigureAmplitudeResponse\x12k\n\x14\x43onfigureArbSequence\x12(.nifgen_grpc.ConfigureArbSequenceRequest\x1a).nifgen_grpc.ConfigureArbSequenceResponse\x12k\n\x14\x43onfigureArbWaveform\x12(.nifgen_grpc.ConfigureArbWaveformRequest\x1a).nifgen_grpc.ConfigureArbWaveformResponse\x12\x62\n\x11\x43onfigureChannels\x12%.nifgen_grpc.ConfigureChannelsRequest\x1a&.nifgen_grpc.ConfigureChannelsResponse\x12\x65\n\x12\x43onfigureClockMode\x12&.nifgen_grpc.ConfigureClockModeRequest\x1a\'.nifgen_grpc.ConfigureClockModeResponse\x12\x9b\x01\n$ConfigureCustomFIRFilterCoefficients\x12\x38.nifgen_grpc.ConfigureCustomFIRFilterCoefficientsRequest\x1a\x39.nifgen_grpc.ConfigureCustomFIRFilterCoefficientsResponse\x12\x92\x01\n!ConfigureDigitalEdgeScriptTrigger\x12\x35.nifgen_grpc.ConfigureDigitalEdgeScriptTriggerRequest\x1a\x36.nifgen_grpc.ConfigureDigitalEdgeScriptTriggerResponse\x12\x8f\x01\n ConfigureDigitalEdgeStartTrigger\x12\x34.nifgen_grpc.ConfigureDigitalEdgeStartTriggerRequest\x1a\x35.nifgen_grpc.ConfigureDigitalEdgeStartTriggerResponse\x12\x95\x01\n\"ConfigureDigitalLevelScriptTrigger\x12\x36.nifgen_grpc.ConfigureDigitalLevelScriptTriggerRequest\x1a\x37.nifgen_grpc.ConfigureDigitalLevelScriptTriggerResponse\x12\x62\n\x11\x43onfigureFreqList\x12%.nifgen_grpc.ConfigureFreqListRequest\x1a&.nifgen_grpc.ConfigureFreqListResponse\x12\x65\n\x12\x43onfigureFrequency\x12&.nifgen_grpc.ConfigureFrequencyRequest\x1a\'.nifgen_grpc.ConfigureFrequencyResponse\x12q\n\x16\x43onfigureOperationMode\x12*.nifgen_grpc.ConfigureOperationModeRequest\x1a+.nifgen_grpc.ConfigureOperationModeResponse\x12q\n\x16\x43onfigureOutputEnabled\x12*.nifgen_grpc.ConfigureOutputEnabledRequest\x1a+.nifgen_grpc.ConfigureOutputEnabledResponse\x12w\n\x18\x43onfigureOutputImpedance\x12,.nifgen_grpc.ConfigureOutputImpedanceRequest\x1a-.nifgen_grpc.ConfigureOutputImpedanceResponse\x12h\n\x13\x43onfigureOutputMode\x12\'.nifgen_grpc.ConfigureOutputModeRequest\x1a(.nifgen_grpc.ConfigureOutputModeResponse\x12\xa7\x01\n(ConfigureP2PEndpointFullnessStartTrigger\x12<.nifgen_grpc.ConfigureP2PEndpointFullnessStartTriggerRequest\x1a=.nifgen_grpc.ConfigureP2PEndpointFullnessStartTriggerResponse\x12t\n\x17\x43onfigureReferenceClock\x12+.nifgen_grpc.ConfigureReferenceClockRequest\x1a,.nifgen_grpc.ConfigureReferenceClockResponse\x12}\n\x1a\x43onfigureSampleClockSource\x12..nifgen_grpc.ConfigureSampleClockSourceRequest\x1a/.nifgen_grpc.ConfigureSampleClockSourceResponse\x12h\n\x13\x43onfigureSampleRate\x12\'.nifgen_grpc.ConfigureSampleRateRequest\x1a(.nifgen_grpc.ConfigureSampleRateResponse\x12\x95\x01\n\"ConfigureSoftwareEdgeScriptTrigger\x12\x36.nifgen_grpc.ConfigureSoftwareEdgeScriptTriggerRequest\x1a\x37.nifgen_grpc.ConfigureSoftwareEdgeScriptTriggerResponse\x12\x92\x01\n!ConfigureSoftwareEdgeStartTrigger\x12\x35.nifgen_grpc.ConfigureSoftwareEdgeStartTriggerRequest\x1a\x36.nifgen_grpc.ConfigureSoftwareEdgeStartTriggerResponse\x12z\n\x19\x43onfigureStandardWaveform\x12-.nifgen_grpc.ConfigureStandardWaveformRequest\x1a..nifgen_grpc.ConfigureStandardWaveformResponse\x12w\n\x18\x43onfigureSynchronization\x12,.nifgen_grpc.ConfigureSynchronizationRequest\x1a-.nifgen_grpc.ConfigureSynchronizationResponse\x12k\n\x14\x43onfigureTriggerMode\x12(.nifgen_grpc.ConfigureTriggerModeRequest\x1a).nifgen_grpc.ConfigureTriggerModeResponse\x12z\n\x19\x43reateAdvancedArbSequence\x12-.nifgen_grpc.CreateAdvancedArbSequenceRequest\x1a..nifgen_grpc.CreateAdvancedArbSequenceResponse\x12\x62\n\x11\x43reateArbSequence\x12%.nifgen_grpc.CreateArbSequenceRequest\x1a&.nifgen_grpc.CreateArbSequenceResponse\x12Y\n\x0e\x43reateFreqList\x12\".nifgen_grpc.CreateFreqListRequest\x1a#.nifgen_grpc.CreateFreqListResponse\x12w\n\x18\x43reateWaveformComplexF64\x12,.nifgen_grpc.CreateWaveformComplexF64Request\x1a-.nifgen_grpc.CreateWaveformComplexF64Response\x12\x62\n\x11\x43reateWaveformF64\x12%.nifgen_grpc.CreateWaveformF64Request\x1a&.nifgen_grpc.CreateWaveformF64Response\x12z\n\x19\x43reateWaveformFromFileF64\x12-.nifgen_grpc.CreateWaveformFromFileF64Request\x1a..nifgen_grpc.CreateWaveformFromFileF64Response\x12z\n\x19\x43reateWaveformFromFileHWS\x12-.nifgen_grpc.CreateWaveformFromFileHWSRequest\x1a..nifgen_grpc.CreateWaveformFromFileHWSResponse\x12z\n\x19\x43reateWaveformFromFileI16\x12-.nifgen_grpc.CreateWaveformFromFileI16Request\x1a..nifgen_grpc.CreateWaveformFromFileI16Response\x12\x62\n\x11\x43reateWaveformI16\x12%.nifgen_grpc.CreateWaveformI16Request\x1a&.nifgen_grpc.CreateWaveformI16Response\x12}\n\x1a\x44\x65\x66ineUserStandardWaveform\x12..nifgen_grpc.DefineUserStandardWaveformRequest\x1a/.nifgen_grpc.DefineUserStandardWaveformResponse\x12h\n\x13\x44\x65leteNamedWaveform\x12\'.nifgen_grpc.DeleteNamedWaveformRequest\x1a(.nifgen_grpc.DeleteNamedWaveformResponse\x12S\n\x0c\x44\x65leteScript\x12 .nifgen_grpc.DeleteScriptRequest\x1a!.nifgen_grpc.DeleteScriptResponse\x12\x44\n\x07\x44isable\x12\x1b.nifgen_grpc.DisableRequest\x1a\x1c.nifgen_grpc.DisableResponse\x12h\n\x13\x44isableAnalogFilter\x12\'.nifgen_grpc.DisableAnalogFilterRequest\x1a(.nifgen_grpc.DisableAnalogFilterResponse\x12k\n\x14\x44isableDigitalFilter\x12(.nifgen_grpc.DisableDigitalFilterRequest\x1a).nifgen_grpc.DisableDigitalFilterResponse\x12w\n\x18\x44isableDigitalPatterning\x12,.nifgen_grpc.DisableDigitalPatterningRequest\x1a-.nifgen_grpc.DisableDigitalPatterningResponse\x12k\n\x14\x44isableScriptTrigger\x12(.nifgen_grpc.DisableScriptTriggerRequest\x1a).nifgen_grpc.DisableScriptTriggerResponse\x12h\n\x13\x44isableStartTrigger\x12\'.nifgen_grpc.DisableStartTriggerRequest\x1a(.nifgen_grpc.DisableStartTriggerResponse\x12\x65\n\x12\x45nableAnalogFilter\x12&.nifgen_grpc.EnableAnalogFilterRequest\x1a\'.nifgen_grpc.EnableAnalogFilterResponse\x12h\n\x13\x45nableDigitalFilter\x12\'.nifgen_grpc.EnableDigitalFilterRequest\x1a(.nifgen_grpc.EnableDigitalFilterResponse\x12t\n\x17\x45nableDigitalPatterning\x12+.nifgen_grpc.EnableDigitalPatterningRequest\x1a,.nifgen_grpc.EnableDigitalPatterningResponse\x12S\n\x0c\x45rrorHandler\x12 .nifgen_grpc.ErrorHandlerRequest\x1a!.nifgen_grpc.ErrorHandlerResponse\x12S\n\x0c\x45rrorMessage\x12 .nifgen_grpc.ErrorMessageRequest\x1a!.nifgen_grpc.ErrorMessageResponse\x12M\n\nErrorQuery\x12\x1e.nifgen_grpc.ErrorQueryRequest\x1a\x1f.nifgen_grpc.ErrorQueryResponse\x12\x95\x01\n\"ExportAttributeConfigurationBuffer\x12\x36.nifgen_grpc.ExportAttributeConfigurationBufferRequest\x1a\x37.nifgen_grpc.ExportAttributeConfigurationBufferResponse\x12\x8f\x01\n ExportAttributeConfigurationFile\x12\x34.nifgen_grpc.ExportAttributeConfigurationFileRequest\x1a\x35.nifgen_grpc.ExportAttributeConfigurationFileResponse\x12S\n\x0c\x45xportSignal\x12 .nifgen_grpc.ExportSignalRequest\x1a!.nifgen_grpc.ExportSignalResponse\x12n\n\x15GetAttributeViBoolean\x12).nifgen_grpc.GetAttributeViBooleanRequest\x1a*.nifgen_grpc.GetAttributeViBooleanResponse\x12h\n\x13GetAttributeViInt32\x12\'.nifgen_grpc.GetAttributeViInt32Request\x1a(.nifgen_grpc.GetAttributeViInt32Response\x12h\n\x13GetAttributeViInt64\x12\'.nifgen_grpc.GetAttributeViInt64Request\x1a(.nifgen_grpc.GetAttributeViInt64Response\x12k\n\x14GetAttributeViReal64\x12(.nifgen_grpc.GetAttributeViReal64Request\x1a).nifgen_grpc.GetAttributeViReal64Response\x12n\n\x15GetAttributeViSession\x12).nifgen_grpc.GetAttributeViSessionRequest\x1a*.nifgen_grpc.GetAttributeViSessionResponse\x12k\n\x14GetAttributeViString\x12(.nifgen_grpc.GetAttributeViStringRequest\x1a).nifgen_grpc.GetAttributeViStringResponse\x12Y\n\x0eGetChannelName\x12\".nifgen_grpc.GetChannelNameRequest\x1a#.nifgen_grpc.GetChannelNameResponse\x12G\n\x08GetError\x12\x1c.nifgen_grpc.GetErrorRequest\x1a\x1d.nifgen_grpc.GetErrorResponse\x12w\n\x18GetExtCalLastDateAndTime\x12,.nifgen_grpc.GetExtCalLastDateAndTimeRequest\x1a-.nifgen_grpc.GetExtCalLastDateAndTimeResponse\x12\x62\n\x11GetExtCalLastTemp\x12%.nifgen_grpc.GetExtCalLastTempRequest\x1a&.nifgen_grpc.GetExtCalLastTempResponse\x12\x83\x01\n\x1cGetExtCalRecommendedInterval\x12\x30.nifgen_grpc.GetExtCalRecommendedIntervalRequest\x1a\x31.nifgen_grpc.GetExtCalRecommendedIntervalResponse\x12w\n\x18GetFIRFilterCoefficients\x12,.nifgen_grpc.GetFIRFilterCoefficientsRequest\x1a-.nifgen_grpc.GetFIRFilterCoefficientsResponse\x12_\n\x10GetHardwareState\x12$.nifgen_grpc.GetHardwareStateRequest\x1a%.nifgen_grpc.GetHardwareStateResponse\x12n\n\x15GetNextCoercionRecord\x12).nifgen_grpc.GetNextCoercionRecordRequest\x1a*.nifgen_grpc.GetNextCoercionRecordResponse\x12z\n\x19GetNextInterchangeWarning\x12-.nifgen_grpc.GetNextInterchangeWarningRequest\x1a..nifgen_grpc.GetNextInterchangeWarningResponse\x12z\n\x19GetSelfCalLastDateAndTime\x12-.nifgen_grpc.GetSelfCalLastDateAndTimeRequest\x1a..nifgen_grpc.GetSelfCalLastDateAndTimeResponse\x12\x65\n\x12GetSelfCalLastTemp\x12&.nifgen_grpc.GetSelfCalLastTempRequest\x1a\'.nifgen_grpc.GetSelfCalLastTempResponse\x12h\n\x13GetSelfCalSupported\x12\'.nifgen_grpc.GetSelfCalSupportedRequest\x1a(.nifgen_grpc.GetSelfCalSupportedResponse\x12t\n\x17GetStreamEndpointHandle\x12+.nifgen_grpc.GetStreamEndpointHandleRequest\x1a,.nifgen_grpc.GetStreamEndpointHandleResponse\x12\x95\x01\n\"ImportAttributeConfigurationBuffer\x12\x36.nifgen_grpc.ImportAttributeConfigurationBufferRequest\x1a\x37.nifgen_grpc.ImportAttributeConfigurationBufferResponse\x12\x8f\x01\n ImportAttributeConfigurationFile\x12\x34.nifgen_grpc.ImportAttributeConfigurationFileRequest\x1a\x35.nifgen_grpc.ImportAttributeConfigurationFileResponse\x12;\n\x04Init\x12\x18.nifgen_grpc.InitRequest\x1a\x19.nifgen_grpc.InitResponse\x12\\\n\x0fInitWithOptions\x12#.nifgen_grpc.InitWithOptionsRequest\x1a$.nifgen_grpc.InitWithOptionsResponse\x12q\n\x16InitializeWithChannels\x12*.nifgen_grpc.InitializeWithChannelsRequest\x1a+.nifgen_grpc.InitializeWithChannelsResponse\x12\x65\n\x12InitiateGeneration\x12&.nifgen_grpc.InitiateGenerationRequest\x1a\'.nifgen_grpc.InitiateGenerationResponse\x12t\n\x17InvalidateAllAttributes\x12+.nifgen_grpc.InvalidateAllAttributesRequest\x1a,.nifgen_grpc.InvalidateAllAttributesResponse\x12\x41\n\x06IsDone\x12\x1a.nifgen_grpc.IsDoneRequest\x1a\x1b.nifgen_grpc.IsDoneResponse\x12n\n\x15ManualEnableP2PStream\x12).nifgen_grpc.ManualEnableP2PStreamRequest\x1a*.nifgen_grpc.ManualEnableP2PStreamResponse\x12t\n\x17QueryArbSeqCapabilities\x12+.nifgen_grpc.QueryArbSeqCapabilitiesRequest\x1a,.nifgen_grpc.QueryArbSeqCapabilitiesResponse\x12t\n\x17QueryArbWfmCapabilities\x12+.nifgen_grpc.QueryArbWfmCapabilitiesRequest\x1a,.nifgen_grpc.QueryArbWfmCapabilitiesResponse\x12z\n\x19QueryFreqListCapabilities\x12-.nifgen_grpc.QueryFreqListCapabilitiesRequest\x1a..nifgen_grpc.QueryFreqListCapabilitiesResponse\x12q\n\x16ReadCurrentTemperature\x12*.nifgen_grpc.ReadCurrentTemperatureRequest\x1a+.nifgen_grpc.ReadCurrentTemperatureResponse\x12>\n\x05Reset\x12\x19.nifgen_grpc.ResetRequest\x1a\x1a.nifgen_grpc.ResetResponse\x12Y\n\x0eResetAttribute\x12\".nifgen_grpc.ResetAttributeRequest\x1a#.nifgen_grpc.ResetAttributeResponse\x12P\n\x0bResetDevice\x12\x1f.nifgen_grpc.ResetDeviceRequest\x1a .nifgen_grpc.ResetDeviceResponse\x12n\n\x15ResetInterchangeCheck\x12).nifgen_grpc.ResetInterchangeCheckRequest\x1a*.nifgen_grpc.ResetInterchangeCheckResponse\x12\x62\n\x11ResetWithDefaults\x12%.nifgen_grpc.ResetWithDefaultsRequest\x1a&.nifgen_grpc.ResetWithDefaultsResponse\x12V\n\rRevisionQuery\x12!.nifgen_grpc.RevisionQueryRequest\x1a\".nifgen_grpc.RevisionQueryResponse\x12Y\n\x0eRouteSignalOut\x12\".nifgen_grpc.RouteSignalOutRequest\x1a#.nifgen_grpc.RouteSignalOutResponse\x12\x44\n\x07SelfCal\x12\x1b.nifgen_grpc.SelfCalRequest\x1a\x1c.nifgen_grpc.SelfCalResponse\x12G\n\x08SelfTest\x12\x1c.nifgen_grpc.SelfTestRequest\x1a\x1d.nifgen_grpc.SelfTestResponse\x12t\n\x17SendSoftwareEdgeTrigger\x12+.nifgen_grpc.SendSoftwareEdgeTriggerRequest\x1a,.nifgen_grpc.SendSoftwareEdgeTriggerResponse\x12n\n\x15SetAttributeViBoolean\x12).nifgen_grpc.SetAttributeViBooleanRequest\x1a*.nifgen_grpc.SetAttributeViBooleanResponse\x12h\n\x13SetAttributeViInt32\x12\'.nifgen_grpc.SetAttributeViInt32Request\x1a(.nifgen_grpc.SetAttributeViInt32Response\x12h\n\x13SetAttributeViInt64\x12\'.nifgen_grpc.SetAttributeViInt64Request\x1a(.nifgen_grpc.SetAttributeViInt64Response\x12k\n\x14SetAttributeViReal64\x12(.nifgen_grpc.SetAttributeViReal64Request\x1a).nifgen_grpc.SetAttributeViReal64Response\x12n\n\x15SetAttributeViSession\x12).nifgen_grpc.SetAttributeViSessionRequest\x1a*.nifgen_grpc.SetAttributeViSessionResponse\x12k\n\x14SetAttributeViString\x12(.nifgen_grpc.SetAttributeViStringRequest\x1a).nifgen_grpc.SetAttributeViStringResponse\x12\x92\x01\n!SetNamedWaveformNextWritePosition\x12\x35.nifgen_grpc.SetNamedWaveformNextWritePositionRequest\x1a\x36.nifgen_grpc.SetNamedWaveformNextWritePositionResponse\x12\x83\x01\n\x1cSetWaveformNextWritePosition\x12\x30.nifgen_grpc.SetWaveformNextWritePositionRequest\x1a\x31.nifgen_grpc.SetWaveformNextWritePositionResponse\x12V\n\rWaitUntilDone\x12!.nifgen_grpc.WaitUntilDoneRequest\x1a\".nifgen_grpc.WaitUntilDoneResponse\x12n\n\x15WriteBinary16Waveform\x12).nifgen_grpc.WriteBinary16WaveformRequest\x1a*.nifgen_grpc.WriteBinary16WaveformResponse\x12\x83\x01\n\x1cWriteComplexBinary16Waveform\x12\x30.nifgen_grpc.WriteComplexBinary16WaveformRequest\x1a\x31.nifgen_grpc.WriteComplexBinary16WaveformResponse\x12\x83\x01\n\x1cWriteNamedWaveformComplexF64\x12\x30.nifgen_grpc.WriteNamedWaveformComplexF64Request\x1a\x31.nifgen_grpc.WriteNamedWaveformComplexF64Response\x12\x83\x01\n\x1cWriteNamedWaveformComplexI16\x12\x30.nifgen_grpc.WriteNamedWaveformComplexI16Request\x1a\x31.nifgen_grpc.WriteNamedWaveformComplexI16Response\x12n\n\x15WriteNamedWaveformF64\x12).nifgen_grpc.WriteNamedWaveformF64Request\x1a*.nifgen_grpc.WriteNamedWaveformF64Response\x12n\n\x15WriteNamedWaveformI16\x12).nifgen_grpc.WriteNamedWaveformI16Request\x1a*.nifgen_grpc.WriteNamedWaveformI16Response\x12h\n\x13WriteP2PEndpointI16\x12\'.nifgen_grpc.WriteP2PEndpointI16Request\x1a(.nifgen_grpc.WriteP2PEndpointI16Response\x12P\n\x0bWriteScript\x12\x1f.nifgen_grpc.WriteScriptRequest\x1a .nifgen_grpc.WriteScriptResponse\x12V\n\rWriteWaveform\x12!.nifgen_grpc.WriteWaveformRequest\x1a\".nifgen_grpc.WriteWaveformResponse\x12t\n\x17WriteWaveformComplexF64\x12+.nifgen_grpc.WriteWaveformComplexF64Request\x1a,.nifgen_grpc.WriteWaveformComplexF64ResponseB<\n\x10\x63om.ni.grpc.fgenB\x06NiFgenP\x01\xaa\x02\x1dNationalInstruments.Grpc.Fgenb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nifgen_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020com.ni.grpc.fgenB\006NiFgenP\001\252\002\035NationalInstruments.Grpc.Fgen'
  _NIFGENINT32ATTRIBUTEVALUES._options = None
  _NIFGENINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _NIFGENREAL64ATTRIBUTEVALUES._options = None
  _NIFGENREAL64ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _INITRESPONSE.fields_by_name['error_message']._options = None
  _INITRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _INITWITHOPTIONSRESPONSE.fields_by_name['error_message']._options = None
  _INITWITHOPTIONSRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _INITIALIZEWITHCHANNELSRESPONSE.fields_by_name['error_message']._options = None
  _INITIALIZEWITHCHANNELSRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _NIFGENATTRIBUTE._serialized_start=24956
  _NIFGENATTRIBUTE._serialized_end=35621
  _BYTEORDER._serialized_start=35623
  _BYTEORDER._serialized_end=35713
  _CLOCKMODE._serialized_start=35716
  _CLOCKMODE._serialized_end=35846
  _FREQUENCYLISTOPTIONS._serialized_start=35848
  _FREQUENCYLISTOPTIONS._serialized_end=35969
  _HARDWARESTATE._serialized_start=35972
  _HARDWARESTATE._serialized_end=36204
  _NIFGENINT32ATTRIBUTEVALUES._serialized_start=36207
  _NIFGENINT32ATTRIBUTEVALUES._serialized_end=46640
  _NIFGENREAL64ATTRIBUTEVALUES._serialized_start=46643
  _NIFGENREAL64ATTRIBUTEVALUES._serialized_end=46938
  _NIFGENSTRINGATTRIBUTEVALUESMAPPED._serialized_start=46941
  _NIFGENSTRINGATTRIBUTEVALUESMAPPED._serialized_end=48300
  _OUTPUTMODE._serialized_start=48303
  _OUTPUTMODE._serialized_end=48520
  _RELATIVETO._serialized_start=48522
  _RELATIVETO._serialized_end=48640
  _ROUTESIGNALFROM._serialized_start=48643
  _ROUTESIGNALFROM._serialized_end=49548
  _ROUTESIGNALTO._serialized_start=49551
  _ROUTESIGNALTO._serialized_end=50080
  _SEQUENCEHANDLE._serialized_start=50082
  _SEQUENCEHANDLE._serialized_end=50186
  _SIGNAL._serialized_start=50189
  _SIGNAL._serialized_end=50733
  _TRIGGER._serialized_start=50735
  _TRIGGER._serialized_end=50847
  _TRIGGERMODE._serialized_start=50850
  _TRIGGERMODE._serialized_end=51041
  _TRIGGERWHEN._serialized_start=51043
  _TRIGGERWHEN._serialized_end=51167
  _WAVEFORM._serialized_start=51170
  _WAVEFORM._serialized_end=51491
  _WAVEFORMHANDLE._serialized_start=51493
  _WAVEFORMHANDLE._serialized_end=51597
  _ABORTGENERATIONREQUEST._serialized_start=60
  _ABORTGENERATIONREQUEST._serialized_end=120
  _ABORTGENERATIONRESPONSE._serialized_start=122
  _ABORTGENERATIONRESPONSE._serialized_end=163
  _ADJUSTSAMPLECLOCKRELATIVEDELAYREQUEST._serialized_start=165
  _ADJUSTSAMPLECLOCKRELATIVEDELAYREQUEST._serialized_end=265
  _ADJUSTSAMPLECLOCKRELATIVEDELAYRESPONSE._serialized_start=267
  _ADJUSTSAMPLECLOCKRELATIVEDELAYRESPONSE._serialized_end=323
  _ALLOCATENAMEDWAVEFORMREQUEST._serialized_start=326
  _ALLOCATENAMEDWAVEFORMREQUEST._serialized_end=460
  _ALLOCATENAMEDWAVEFORMRESPONSE._serialized_start=462
  _ALLOCATENAMEDWAVEFORMRESPONSE._serialized_end=509
  _ALLOCATEWAVEFORMREQUEST._serialized_start=511
  _ALLOCATEWAVEFORMREQUEST._serialized_end=617
  _ALLOCATEWAVEFORMRESPONSE._serialized_start=619
  _ALLOCATEWAVEFORMRESPONSE._serialized_end=686
  _CHECKATTRIBUTEVIBOOLEANREQUEST._serialized_start=689
  _CHECKATTRIBUTEVIBOOLEANREQUEST._serialized_end=856
  _CHECKATTRIBUTEVIBOOLEANRESPONSE._serialized_start=858
  _CHECKATTRIBUTEVIBOOLEANRESPONSE._serialized_end=907
  _CHECKATTRIBUTEVIINT32REQUEST._serialized_start=910
  _CHECKATTRIBUTEVIINT32REQUEST._serialized_end=1173
  _CHECKATTRIBUTEVIINT32RESPONSE._serialized_start=1175
  _CHECKATTRIBUTEVIINT32RESPONSE._serialized_end=1222
  _CHECKATTRIBUTEVIINT64REQUEST._serialized_start=1225
  _CHECKATTRIBUTEVIINT64REQUEST._serialized_end=1394
  _CHECKATTRIBUTEVIINT64RESPONSE._serialized_start=1396
  _CHECKATTRIBUTEVIINT64RESPONSE._serialized_end=1443
  _CHECKATTRIBUTEVIREAL64REQUEST._serialized_start=1446
  _CHECKATTRIBUTEVIREAL64REQUEST._serialized_end=1711
  _CHECKATTRIBUTEVIREAL64RESPONSE._serialized_start=1713
  _CHECKATTRIBUTEVIREAL64RESPONSE._serialized_end=1761
  _CHECKATTRIBUTEVISESSIONREQUEST._serialized_start=1764
  _CHECKATTRIBUTEVISESSIONREQUEST._serialized_end=1955
  _CHECKATTRIBUTEVISESSIONRESPONSE._serialized_start=1957
  _CHECKATTRIBUTEVISESSIONRESPONSE._serialized_end=2006
  _CHECKATTRIBUTEVISTRINGREQUEST._serialized_start=2009
  _CHECKATTRIBUTEVISTRINGREQUEST._serialized_end=2287
  _CHECKATTRIBUTEVISTRINGRESPONSE._serialized_start=2289
  _CHECKATTRIBUTEVISTRINGRESPONSE._serialized_end=2337
  _CLEARARBMEMORYREQUEST._serialized_start=2339
  _CLEARARBMEMORYREQUEST._serialized_end=2398
  _CLEARARBMEMORYRESPONSE._serialized_start=2400
  _CLEARARBMEMORYRESPONSE._serialized_end=2440
  _CLEARARBSEQUENCEREQUEST._serialized_start=2443
  _CLEARARBSEQUENCEREQUEST._serialized_end=2615
  _CLEARARBSEQUENCERESPONSE._serialized_start=2617
  _CLEARARBSEQUENCERESPONSE._serialized_end=2659
  _CLEARARBWAVEFORMREQUEST._serialized_start=2662
  _CLEARARBWAVEFORMREQUEST._serialized_end=2834
  _CLEARARBWAVEFORMRESPONSE._serialized_start=2836
  _CLEARARBWAVEFORMRESPONSE._serialized_end=2878
  _CLEARERRORREQUEST._serialized_start=2880
  _CLEARERRORREQUEST._serialized_end=2935
  _CLEARERRORRESPONSE._serialized_start=2937
  _CLEARERRORRESPONSE._serialized_end=2973
  _CLEARFREQLISTREQUEST._serialized_start=2976
  _CLEARFREQLISTREQUEST._serialized_end=3169
  _CLEARFREQLISTRESPONSE._serialized_start=3171
  _CLEARFREQLISTRESPONSE._serialized_end=3210
  _CLEARINTERCHANGEWARNINGSREQUEST._serialized_start=3212
  _CLEARINTERCHANGEWARNINGSREQUEST._serialized_end=3281
  _CLEARINTERCHANGEWARNINGSRESPONSE._serialized_start=3283
  _CLEARINTERCHANGEWARNINGSRESPONSE._serialized_end=3333
  _CLEARUSERSTANDARDWAVEFORMREQUEST._serialized_start=3335
  _CLEARUSERSTANDARDWAVEFORMREQUEST._serialized_end=3427
  _CLEARUSERSTANDARDWAVEFORMRESPONSE._serialized_start=3429
  _CLEARUSERSTANDARDWAVEFORMRESPONSE._serialized_end=3480
  _CLOSEREQUEST._serialized_start=3482
  _CLOSEREQUEST._serialized_end=3532
  _CLOSERESPONSE._serialized_start=3534
  _CLOSERESPONSE._serialized_end=3565
  _COMMITREQUEST._serialized_start=3567
  _COMMITREQUEST._serialized_end=3618
  _COMMITRESPONSE._serialized_start=3620
  _COMMITRESPONSE._serialized_end=3652
  _CONFIGUREAMPLITUDEREQUEST._serialized_start=3654
  _CONFIGUREAMPLITUDEREQUEST._serialized_end=3758
  _CONFIGUREAMPLITUDERESPONSE._serialized_start=3760
  _CONFIGUREAMPLITUDERESPONSE._serialized_end=3804
  _CONFIGUREARBSEQUENCEREQUEST._serialized_start=3807
  _CONFIGUREARBSEQUENCEREQUEST._serialized_end=3949
  _CONFIGUREARBSEQUENCERESPONSE._serialized_start=3951
  _CONFIGUREARBSEQUENCERESPONSE._serialized_end=3997
  _CONFIGUREARBWAVEFORMREQUEST._serialized_start=4000
  _CONFIGUREARBWAVEFORMREQUEST._serialized_end=4142
  _CONFIGUREARBWAVEFORMRESPONSE._serialized_start=4144
  _CONFIGUREARBWAVEFORMRESPONSE._serialized_end=4190
  _CONFIGURECHANNELSREQUEST._serialized_start=4192
  _CONFIGURECHANNELSREQUEST._serialized_end=4272
  _CONFIGURECHANNELSRESPONSE._serialized_start=4274
  _CONFIGURECHANNELSRESPONSE._serialized_end=4317
  _CONFIGURECLOCKMODEREQUEST._serialized_start=4320
  _CONFIGURECLOCKMODEREQUEST._serialized_end=4474
  _CONFIGURECLOCKMODERESPONSE._serialized_start=4476
  _CONFIGURECLOCKMODERESPONSE._serialized_end=4520
  _CONFIGURECUSTOMFIRFILTERCOEFFICIENTSREQUEST._serialized_start=4523
  _CONFIGURECUSTOMFIRFILTERCOEFFICIENTSREQUEST._serialized_end=4654
  _CONFIGURECUSTOMFIRFILTERCOEFFICIENTSRESPONSE._serialized_start=4656
  _CONFIGURECUSTOMFIRFILTERCOEFFICIENTSRESPONSE._serialized_end=4718
  _CONFIGUREDIGITALEDGESCRIPTTRIGGERREQUEST._serialized_start=4721
  _CONFIGUREDIGITALEDGESCRIPTTRIGGERREQUEST._serialized_end=4849
  _CONFIGUREDIGITALEDGESCRIPTTRIGGERRESPONSE._serialized_start=4851
  _CONFIGUREDIGITALEDGESCRIPTTRIGGERRESPONSE._serialized_end=4910
  _CONFIGUREDIGITALEDGESTARTTRIGGERREQUEST._serialized_start=4912
  _CONFIGUREDIGITALEDGESTARTTRIGGERREQUEST._serialized_end=5019
  _CONFIGUREDIGITALEDGESTARTTRIGGERRESPONSE._serialized_start=5021
  _CONFIGUREDIGITALEDGESTARTTRIGGERRESPONSE._serialized_end=5079
  _CONFIGUREDIGITALLEVELSCRIPTTRIGGERREQUEST._serialized_start=5082
  _CONFIGUREDIGITALLEVELSCRIPTTRIGGERREQUEST._serialized_end=5296
  _CONFIGUREDIGITALLEVELSCRIPTTRIGGERRESPONSE._serialized_start=5298
  _CONFIGUREDIGITALLEVELSCRIPTTRIGGERRESPONSE._serialized_end=5358
  _CONFIGUREFREQLISTREQUEST._serialized_start=5361
  _CONFIGUREFREQLISTREQUEST._serialized_end=5535
  _CONFIGUREFREQLISTRESPONSE._serialized_start=5537
  _CONFIGUREFREQLISTRESPONSE._serialized_end=5580
  _CONFIGUREFREQUENCYREQUEST._serialized_start=5582
  _CONFIGUREFREQUENCYREQUEST._serialized_end=5686
  _CONFIGUREFREQUENCYRESPONSE._serialized_start=5688
  _CONFIGUREFREQUENCYRESPONSE._serialized_end=5732
  _CONFIGUREOPERATIONMODEREQUEST._serialized_start=5734
  _CONFIGUREOPERATIONMODEREQUEST._serialized_end=5847
  _CONFIGUREOPERATIONMODERESPONSE._serialized_start=5849
  _CONFIGUREOPERATIONMODERESPONSE._serialized_end=5897
  _CONFIGUREOUTPUTENABLEDREQUEST._serialized_start=5899
  _CONFIGUREOUTPUTENABLEDREQUEST._serialized_end=6005
  _CONFIGUREOUTPUTENABLEDRESPONSE._serialized_start=6007
  _CONFIGUREOUTPUTENABLEDRESPONSE._serialized_end=6055
  _CONFIGUREOUTPUTIMPEDANCEREQUEST._serialized_start=6057
  _CONFIGUREOUTPUTIMPEDANCEREQUEST._serialized_end=6167
  _CONFIGUREOUTPUTIMPEDANCERESPONSE._serialized_start=6169
  _CONFIGUREOUTPUTIMPEDANCERESPONSE._serialized_end=6219
  _CONFIGUREOUTPUTMODEREQUEST._serialized_start=6222
  _CONFIGUREOUTPUTMODEREQUEST._serialized_end=6381
  _CONFIGUREOUTPUTMODERESPONSE._serialized_start=6383
  _CONFIGUREOUTPUTMODERESPONSE._serialized_end=6428
  _CONFIGUREP2PENDPOINTFULLNESSSTARTTRIGGERREQUEST._serialized_start=6430
  _CONFIGUREP2PENDPOINTFULLNESSSTARTTRIGGERREQUEST._serialized_end=6552
  _CONFIGUREP2PENDPOINTFULLNESSSTARTTRIGGERRESPONSE._serialized_start=6554
  _CONFIGUREP2PENDPOINTFULLNESSSTARTTRIGGERRESPONSE._serialized_end=6620
  _CONFIGUREREFERENCECLOCKREQUEST._serialized_start=6623
  _CONFIGUREREFERENCECLOCKREQUEST._serialized_end=6758
  _CONFIGUREREFERENCECLOCKRESPONSE._serialized_start=6760
  _CONFIGUREREFERENCECLOCKRESPONSE._serialized_end=6809
  _CONFIGURESAMPLECLOCKSOURCEREQUEST._serialized_start=6811
  _CONFIGURESAMPLECLOCKSOURCEREQUEST._serialized_end=6911
  _CONFIGURESAMPLECLOCKSOURCERESPONSE._serialized_start=6913
  _CONFIGURESAMPLECLOCKSOURCERESPONSE._serialized_end=6965
  _CONFIGURESAMPLERATEREQUEST._serialized_start=6967
  _CONFIGURESAMPLERATEREQUEST._serialized_end=7052
  _CONFIGURESAMPLERATERESPONSE._serialized_start=7054
  _CONFIGURESAMPLERATERESPONSE._serialized_end=7099
  _CONFIGURESOFTWAREEDGESCRIPTTRIGGERREQUEST._serialized_start=7101
  _CONFIGURESOFTWAREEDGESCRIPTTRIGGERREQUEST._serialized_end=7200
  _CONFIGURESOFTWAREEDGESCRIPTTRIGGERRESPONSE._serialized_start=7202
  _CONFIGURESOFTWAREEDGESCRIPTTRIGGERRESPONSE._serialized_end=7262
  _CONFIGURESOFTWAREEDGESTARTTRIGGERREQUEST._serialized_start=7264
  _CONFIGURESOFTWAREEDGESTARTTRIGGERREQUEST._serialized_end=7342
  _CONFIGURESOFTWAREEDGESTARTTRIGGERRESPONSE._serialized_start=7344
  _CONFIGURESOFTWAREEDGESTARTTRIGGERRESPONSE._serialized_end=7403
  _CONFIGURESTANDARDWAVEFORMREQUEST._serialized_start=7406
  _CONFIGURESTANDARDWAVEFORMREQUEST._serialized_end=7660
  _CONFIGURESTANDARDWAVEFORMRESPONSE._serialized_start=7662
  _CONFIGURESTANDARDWAVEFORMRESPONSE._serialized_end=7713
  _CONFIGURESYNCHRONIZATIONREQUEST._serialized_start=7715
  _CONFIGURESYNCHRONIZATIONREQUEST._serialized_end=7838
  _CONFIGURESYNCHRONIZATIONRESPONSE._serialized_start=7840
  _CONFIGURESYNCHRONIZATIONRESPONSE._serialized_end=7890
  _CONFIGURETRIGGERMODEREQUEST._serialized_start=7893
  _CONFIGURETRIGGERMODEREQUEST._serialized_end=8079
  _CONFIGURETRIGGERMODERESPONSE._serialized_start=8081
  _CONFIGURETRIGGERMODERESPONSE._serialized_end=8127
  _CREATEADVANCEDARBSEQUENCEREQUEST._serialized_start=8130
  _CREATEADVANCEDARBSEQUENCEREQUEST._serialized_end=8319
  _CREATEADVANCEDARBSEQUENCERESPONSE._serialized_start=8321
  _CREATEADVANCEDARBSEQUENCERESPONSE._serialized_end=8428
  _CREATEARBSEQUENCEREQUEST._serialized_start=8430
  _CREATEARBSEQUENCEREQUEST._serialized_end=8551
  _CREATEARBSEQUENCERESPONSE._serialized_start=8553
  _CREATEARBSEQUENCERESPONSE._serialized_end=8621
  _CREATEFREQLISTREQUEST._serialized_start=8624
  _CREATEFREQLISTREQUEST._serialized_end=8816
  _CREATEFREQLISTRESPONSE._serialized_start=8818
  _CREATEFREQLISTRESPONSE._serialized_end=8889
  _CREATEWAVEFORMCOMPLEXF64REQUEST._serialized_start=8892
  _CREATEWAVEFORMCOMPLEXF64REQUEST._serialized_end=9044
  _CREATEWAVEFORMCOMPLEXF64RESPONSE._serialized_start=9046
  _CREATEWAVEFORMCOMPLEXF64RESPONSE._serialized_end=9121
  _CREATEWAVEFORMF64REQUEST._serialized_start=9123
  _CREATEWAVEFORMF64REQUEST._serialized_end=9236
  _CREATEWAVEFORMF64RESPONSE._serialized_start=9238
  _CREATEWAVEFORMF64RESPONSE._serialized_end=9306
  _CREATEWAVEFORMFROMFILEF64REQUEST._serialized_start=9309
  _CREATEWAVEFORMFROMFILEF64REQUEST._serialized_end=9511
  _CREATEWAVEFORMFROMFILEF64RESPONSE._serialized_start=9513
  _CREATEWAVEFORMFROMFILEF64RESPONSE._serialized_end=9589
  _CREATEWAVEFORMFROMFILEHWSREQUEST._serialized_start=9592
  _CREATEWAVEFORMFROMFILEHWSREQUEST._serialized_end=9778
  _CREATEWAVEFORMFROMFILEHWSRESPONSE._serialized_start=9780
  _CREATEWAVEFORMFROMFILEHWSRESPONSE._serialized_end=9856
  _CREATEWAVEFORMFROMFILEI16REQUEST._serialized_start=9859
  _CREATEWAVEFORMFROMFILEI16REQUEST._serialized_end=10061
  _CREATEWAVEFORMFROMFILEI16RESPONSE._serialized_start=10063
  _CREATEWAVEFORMFROMFILEI16RESPONSE._serialized_end=10139
  _CREATEWAVEFORMI16REQUEST._serialized_start=10141
  _CREATEWAVEFORMI16REQUEST._serialized_end=10254
  _CREATEWAVEFORMI16RESPONSE._serialized_start=10256
  _CREATEWAVEFORMI16RESPONSE._serialized_end=10324
  _DEFINEUSERSTANDARDWAVEFORMREQUEST._serialized_start=10326
  _DEFINEUSERSTANDARDWAVEFORMREQUEST._serialized_end=10448
  _DEFINEUSERSTANDARDWAVEFORMRESPONSE._serialized_start=10450
  _DEFINEUSERSTANDARDWAVEFORMRESPONSE._serialized_end=10502
  _DELETENAMEDWAVEFORMREQUEST._serialized_start=10504
  _DELETENAMEDWAVEFORMREQUEST._serialized_end=10613
  _DELETENAMEDWAVEFORMRESPONSE._serialized_start=10615
  _DELETENAMEDWAVEFORMRESPONSE._serialized_end=10660
  _DELETESCRIPTREQUEST._serialized_start=10662
  _DELETESCRIPTREQUEST._serialized_end=10762
  _DELETESCRIPTRESPONSE._serialized_start=10764
  _DELETESCRIPTRESPONSE._serialized_end=10802
  _DISABLEREQUEST._serialized_start=10804
  _DISABLEREQUEST._serialized_end=10856
  _DISABLERESPONSE._serialized_start=10858
  _DISABLERESPONSE._serialized_end=10891
  _DISABLEANALOGFILTERREQUEST._serialized_start=10893
  _DISABLEANALOGFILTERREQUEST._serialized_end=10979
  _DISABLEANALOGFILTERRESPONSE._serialized_start=10981
  _DISABLEANALOGFILTERRESPONSE._serialized_end=11026
  _DISABLEDIGITALFILTERREQUEST._serialized_start=11028
  _DISABLEDIGITALFILTERREQUEST._serialized_end=11115
  _DISABLEDIGITALFILTERRESPONSE._serialized_start=11117
  _DISABLEDIGITALFILTERRESPONSE._serialized_end=11163
  _DISABLEDIGITALPATTERNINGREQUEST._serialized_start=11165
  _DISABLEDIGITALPATTERNINGREQUEST._serialized_end=11256
  _DISABLEDIGITALPATTERNINGRESPONSE._serialized_start=11258
  _DISABLEDIGITALPATTERNINGRESPONSE._serialized_end=11308
  _DISABLESCRIPTTRIGGERREQUEST._serialized_start=11310
  _DISABLESCRIPTTRIGGERREQUEST._serialized_end=11395
  _DISABLESCRIPTTRIGGERRESPONSE._serialized_start=11397
  _DISABLESCRIPTTRIGGERRESPONSE._serialized_end=11443
  _DISABLESTARTTRIGGERREQUEST._serialized_start=11445
  _DISABLESTARTTRIGGERREQUEST._serialized_end=11509
  _DISABLESTARTTRIGGERRESPONSE._serialized_start=11511
  _DISABLESTARTTRIGGERRESPONSE._serialized_end=11556
  _ENABLEANALOGFILTERREQUEST._serialized_start=11558
  _ENABLEANALOGFILTERREQUEST._serialized_end=11680
  _ENABLEANALOGFILTERRESPONSE._serialized_start=11682
  _ENABLEANALOGFILTERRESPONSE._serialized_end=11726
  _ENABLEDIGITALFILTERREQUEST._serialized_start=11728
  _ENABLEDIGITALFILTERREQUEST._serialized_end=11814
  _ENABLEDIGITALFILTERRESPONSE._serialized_start=11816
  _ENABLEDIGITALFILTERRESPONSE._serialized_end=11861
  _ENABLEDIGITALPATTERNINGREQUEST._serialized_start=11863
  _ENABLEDIGITALPATTERNINGREQUEST._serialized_end=11953
  _ENABLEDIGITALPATTERNINGRESPONSE._serialized_start=11955
  _ENABLEDIGITALPATTERNINGRESPONSE._serialized_end=12004
  _ERRORHANDLERREQUEST._serialized_start=12006
  _ERRORHANDLERREQUEST._serialized_end=12083
  _ERRORHANDLERRESPONSE._serialized_start=12085
  _ERRORHANDLERRESPONSE._serialized_end=12146
  _ERRORMESSAGEREQUEST._serialized_start=12148
  _ERRORMESSAGEREQUEST._serialized_end=12225
  _ERRORMESSAGERESPONSE._serialized_start=12227
  _ERRORMESSAGERESPONSE._serialized_end=12288
  _ERRORQUERYREQUEST._serialized_start=12290
  _ERRORQUERYREQUEST._serialized_end=12345
  _ERRORQUERYRESPONSE._serialized_start=12347
  _ERRORQUERYRESPONSE._serialized_end=12426
  _EXPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_start=12428
  _EXPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_end=12507
  _EXPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_start=12509
  _EXPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_end=12592
  _EXPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_start=12594
  _EXPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_end=12690
  _EXPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_start=12692
  _EXPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_end=12750
  _EXPORTSIGNALREQUEST._serialized_start=12753
  _EXPORTSIGNALREQUEST._serialized_end=12938
  _EXPORTSIGNALRESPONSE._serialized_start=12940
  _EXPORTSIGNALRESPONSE._serialized_end=12978
  _GETATTRIBUTEVIBOOLEANREQUEST._serialized_start=12981
  _GETATTRIBUTEVIBOOLEANREQUEST._serialized_end=13121
  _GETATTRIBUTEVIBOOLEANRESPONSE._serialized_start=13123
  _GETATTRIBUTEVIBOOLEANRESPONSE._serialized_end=13195
  _GETATTRIBUTEVIINT32REQUEST._serialized_start=13198
  _GETATTRIBUTEVIINT32REQUEST._serialized_end=13336
  _GETATTRIBUTEVIINT32RESPONSE._serialized_start=13338
  _GETATTRIBUTEVIINT32RESPONSE._serialized_end=13408
  _GETATTRIBUTEVIINT64REQUEST._serialized_start=13411
  _GETATTRIBUTEVIINT64REQUEST._serialized_end=13549
  _GETATTRIBUTEVIINT64RESPONSE._serialized_start=13551
  _GETATTRIBUTEVIINT64RESPONSE._serialized_end=13621
  _GETATTRIBUTEVIREAL64REQUEST._serialized_start=13624
  _GETATTRIBUTEVIREAL64REQUEST._serialized_end=13763
  _GETATTRIBUTEVIREAL64RESPONSE._serialized_start=13765
  _GETATTRIBUTEVIREAL64RESPONSE._serialized_end=13836
  _GETATTRIBUTEVISESSIONREQUEST._serialized_start=13839
  _GETATTRIBUTEVISESSIONREQUEST._serialized_end=13979
  _GETATTRIBUTEVISESSIONRESPONSE._serialized_start=13981
  _GETATTRIBUTEVISESSIONRESPONSE._serialized_end=14077
  _GETATTRIBUTEVISTRINGREQUEST._serialized_start=14080
  _GETATTRIBUTEVISTRINGREQUEST._serialized_end=14219
  _GETATTRIBUTEVISTRINGRESPONSE._serialized_start=14221
  _GETATTRIBUTEVISTRINGRESPONSE._serialized_end=14292
  _GETCHANNELNAMEREQUEST._serialized_start=14294
  _GETCHANNELNAMEREQUEST._serialized_end=14368
  _GETCHANNELNAMERESPONSE._serialized_start=14370
  _GETCHANNELNAMERESPONSE._serialized_end=14434
  _GETERRORREQUEST._serialized_start=14436
  _GETERRORREQUEST._serialized_end=14489
  _GETERRORRESPONSE._serialized_start=14491
  _GETERRORRESPONSE._serialized_end=14572
  _GETEXTCALLASTDATEANDTIMEREQUEST._serialized_start=14574
  _GETEXTCALLASTDATEANDTIMEREQUEST._serialized_end=14643
  _GETEXTCALLASTDATEANDTIMERESPONSE._serialized_start=14645
  _GETEXTCALLASTDATEANDTIMERESPONSE._serialized_end=14767
  _GETEXTCALLASTTEMPREQUEST._serialized_start=14769
  _GETEXTCALLASTTEMPREQUEST._serialized_end=14831
  _GETEXTCALLASTTEMPRESPONSE._serialized_start=14833
  _GETEXTCALLASTTEMPRESPONSE._serialized_end=14897
  _GETEXTCALRECOMMENDEDINTERVALREQUEST._serialized_start=14899
  _GETEXTCALRECOMMENDEDINTERVALREQUEST._serialized_end=14972
  _GETEXTCALRECOMMENDEDINTERVALRESPONSE._serialized_start=14974
  _GETEXTCALRECOMMENDEDINTERVALRESPONSE._serialized_end=15044
  _GETFIRFILTERCOEFFICIENTSREQUEST._serialized_start=15046
  _GETFIRFILTERCOEFFICIENTSREQUEST._serialized_end=15137
  _GETFIRFILTERCOEFFICIENTSRESPONSE._serialized_start=15139
  _GETFIRFILTERCOEFFICIENTSRESPONSE._serialized_end=15254
  _GETHARDWARESTATEREQUEST._serialized_start=15256
  _GETHARDWARESTATEREQUEST._serialized_end=15317
  _GETHARDWARESTATERESPONSE._serialized_start=15319
  _GETHARDWARESTATERESPONSE._serialized_end=15423
  _GETNEXTCOERCIONRECORDREQUEST._serialized_start=15425
  _GETNEXTCOERCIONRECORDREQUEST._serialized_end=15491
  _GETNEXTCOERCIONRECORDRESPONSE._serialized_start=15493
  _GETNEXTCOERCIONRECORDRESPONSE._serialized_end=15565
  _GETNEXTINTERCHANGEWARNINGREQUEST._serialized_start=15567
  _GETNEXTINTERCHANGEWARNINGREQUEST._serialized_end=15637
  _GETNEXTINTERCHANGEWARNINGRESPONSE._serialized_start=15639
  _GETNEXTINTERCHANGEWARNINGRESPONSE._serialized_end=15719
  _GETSELFCALLASTDATEANDTIMEREQUEST._serialized_start=15721
  _GETSELFCALLASTDATEANDTIMEREQUEST._serialized_end=15791
  _GETSELFCALLASTDATEANDTIMERESPONSE._serialized_start=15793
  _GETSELFCALLASTDATEANDTIMERESPONSE._serialized_end=15916
  _GETSELFCALLASTTEMPREQUEST._serialized_start=15918
  _GETSELFCALLASTTEMPREQUEST._serialized_end=15981
  _GETSELFCALLASTTEMPRESPONSE._serialized_start=15983
  _GETSELFCALLASTTEMPRESPONSE._serialized_end=16048
  _GETSELFCALSUPPORTEDREQUEST._serialized_start=16050
  _GETSELFCALSUPPORTEDREQUEST._serialized_end=16114
  _GETSELFCALSUPPORTEDRESPONSE._serialized_start=16116
  _GETSELFCALSUPPORTEDRESPONSE._serialized_end=16189
  _GETSTREAMENDPOINTHANDLEREQUEST._serialized_start=16191
  _GETSTREAMENDPOINTHANDLEREQUEST._serialized_end=16284
  _GETSTREAMENDPOINTHANDLERESPONSE._serialized_start=16286
  _GETSTREAMENDPOINTHANDLERESPONSE._serialized_end=16358
  _IMPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_start=16360
  _IMPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_end=16462
  _IMPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_start=16464
  _IMPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_end=16524
  _IMPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_start=16526
  _IMPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_end=16622
  _IMPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_start=16624
  _IMPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_end=16682
  _INITREQUEST._serialized_start=16685
  _INITREQUEST._serialized_end=16862
  _INITRESPONSE._serialized_start=16864
  _INITRESPONSE._serialized_end=16990
  _INITWITHOPTIONSREQUEST._serialized_start=16993
  _INITWITHOPTIONSREQUEST._serialized_end=17204
  _INITWITHOPTIONSRESPONSE._serialized_start=17207
  _INITWITHOPTIONSRESPONSE._serialized_end=17344
  _INITIALIZEWITHCHANNELSREQUEST._serialized_start=17347
  _INITIALIZEWITHCHANNELSREQUEST._serialized_end=17569
  _INITIALIZEWITHCHANNELSRESPONSE._serialized_start=17572
  _INITIALIZEWITHCHANNELSRESPONSE._serialized_end=17716
  _INITIATEGENERATIONREQUEST._serialized_start=17718
  _INITIATEGENERATIONREQUEST._serialized_end=17781
  _INITIATEGENERATIONRESPONSE._serialized_start=17783
  _INITIATEGENERATIONRESPONSE._serialized_end=17827
  _INVALIDATEALLATTRIBUTESREQUEST._serialized_start=17829
  _INVALIDATEALLATTRIBUTESREQUEST._serialized_end=17897
  _INVALIDATEALLATTRIBUTESRESPONSE._serialized_start=17899
  _INVALIDATEALLATTRIBUTESRESPONSE._serialized_end=17948
  _ISDONEREQUEST._serialized_start=17950
  _ISDONEREQUEST._serialized_end=18001
  _ISDONERESPONSE._serialized_start=18003
  _ISDONERESPONSE._serialized_end=18049
  _MANUALENABLEP2PSTREAMREQUEST._serialized_start=18051
  _MANUALENABLEP2PSTREAMREQUEST._serialized_end=18140
  _MANUALENABLEP2PSTREAMRESPONSE._serialized_start=18142
  _MANUALENABLEP2PSTREAMRESPONSE._serialized_end=18189
  _QUERYARBSEQCAPABILITIESREQUEST._serialized_start=18191
  _QUERYARBSEQCAPABILITIESREQUEST._serialized_end=18259
  _QUERYARBSEQCAPABILITIESRESPONSE._serialized_start=18262
  _QUERYARBSEQCAPABILITIESRESPONSE._serialized_end=18442
  _QUERYARBWFMCAPABILITIESREQUEST._serialized_start=18444
  _QUERYARBWFMCAPABILITIESREQUEST._serialized_end=18512
  _QUERYARBWFMCAPABILITIESRESPONSE._serialized_start=18515
  _QUERYARBWFMCAPABILITIESRESPONSE._serialized_end=18689
  _QUERYFREQLISTCAPABILITIESREQUEST._serialized_start=18691
  _QUERYFREQLISTCAPABILITIESREQUEST._serialized_end=18761
  _QUERYFREQLISTCAPABILITIESRESPONSE._serialized_start=18764
  _QUERYFREQLISTCAPABILITIESRESPONSE._serialized_end=19054
  _READCURRENTTEMPERATUREREQUEST._serialized_start=19056
  _READCURRENTTEMPERATUREREQUEST._serialized_end=19123
  _READCURRENTTEMPERATURERESPONSE._serialized_start=19125
  _READCURRENTTEMPERATURERESPONSE._serialized_end=19194
  _RESETREQUEST._serialized_start=19196
  _RESETREQUEST._serialized_end=19246
  _RESETRESPONSE._serialized_start=19248
  _RESETRESPONSE._serialized_end=19279
  _RESETATTRIBUTEREQUEST._serialized_start=19282
  _RESETATTRIBUTEREQUEST._serialized_end=19415
  _RESETATTRIBUTERESPONSE._serialized_start=19417
  _RESETATTRIBUTERESPONSE._serialized_end=19457
  _RESETDEVICEREQUEST._serialized_start=19459
  _RESETDEVICEREQUEST._serialized_end=19515
  _RESETDEVICERESPONSE._serialized_start=19517
  _RESETDEVICERESPONSE._serialized_end=19554
  _RESETINTERCHANGECHECKREQUEST._serialized_start=19556
  _RESETINTERCHANGECHECKREQUEST._serialized_end=19622
  _RESETINTERCHANGECHECKRESPONSE._serialized_start=19624
  _RESETINTERCHANGECHECKRESPONSE._serialized_end=19671
  _RESETWITHDEFAULTSREQUEST._serialized_start=19673
  _RESETWITHDEFAULTSREQUEST._serialized_end=19735
  _RESETWITHDEFAULTSRESPONSE._serialized_start=19737
  _RESETWITHDEFAULTSRESPONSE._serialized_end=19780
  _REVISIONQUERYREQUEST._serialized_start=19782
  _REVISIONQUERYREQUEST._serialized_end=19840
  _REVISIONQUERYRESPONSE._serialized_start=19842
  _REVISIONQUERYRESPONSE._serialized_end=19944
  _ROUTESIGNALOUTREQUEST._serialized_start=19947
  _ROUTESIGNALOUTREQUEST._serialized_end=20256
  _ROUTESIGNALOUTRESPONSE._serialized_start=20258
  _ROUTESIGNALOUTRESPONSE._serialized_end=20298
  _SELFCALREQUEST._serialized_start=20300
  _SELFCALREQUEST._serialized_end=20352
  _SELFCALRESPONSE._serialized_start=20354
  _SELFCALRESPONSE._serialized_end=20387
  _SELFTESTREQUEST._serialized_start=20389
  _SELFTESTREQUEST._serialized_end=20442
  _SELFTESTRESPONSE._serialized_start=20444
  _SELFTESTRESPONSE._serialized_end=20531
  _SENDSOFTWAREEDGETRIGGERREQUEST._serialized_start=20534
  _SENDSOFTWAREEDGETRIGGERREQUEST._serialized_end=20702
  _SENDSOFTWAREEDGETRIGGERRESPONSE._serialized_start=20704
  _SENDSOFTWAREEDGETRIGGERRESPONSE._serialized_end=20753
  _SETATTRIBUTEVIBOOLEANREQUEST._serialized_start=20756
  _SETATTRIBUTEVIBOOLEANREQUEST._serialized_end=20921
  _SETATTRIBUTEVIBOOLEANRESPONSE._serialized_start=20923
  _SETATTRIBUTEVIBOOLEANRESPONSE._serialized_end=20970
  _SETATTRIBUTEVIINT32REQUEST._serialized_start=20973
  _SETATTRIBUTEVIINT32REQUEST._serialized_end=21234
  _SETATTRIBUTEVIINT32RESPONSE._serialized_start=21236
  _SETATTRIBUTEVIINT32RESPONSE._serialized_end=21281
  _SETATTRIBUTEVIINT64REQUEST._serialized_start=21284
  _SETATTRIBUTEVIINT64REQUEST._serialized_end=21451
  _SETATTRIBUTEVIINT64RESPONSE._serialized_start=21453
  _SETATTRIBUTEVIINT64RESPONSE._serialized_end=21498
  _SETATTRIBUTEVIREAL64REQUEST._serialized_start=21501
  _SETATTRIBUTEVIREAL64REQUEST._serialized_end=21764
  _SETATTRIBUTEVIREAL64RESPONSE._serialized_start=21766
  _SETATTRIBUTEVIREAL64RESPONSE._serialized_end=21812
  _SETATTRIBUTEVISESSIONREQUEST._serialized_start=21815
  _SETATTRIBUTEVISESSIONREQUEST._serialized_end=22004
  _SETATTRIBUTEVISESSIONRESPONSE._serialized_start=22006
  _SETATTRIBUTEVISESSIONRESPONSE._serialized_end=22053
  _SETATTRIBUTEVISTRINGREQUEST._serialized_start=22056
  _SETATTRIBUTEVISTRINGREQUEST._serialized_end=22332
  _SETATTRIBUTEVISTRINGRESPONSE._serialized_start=22334
  _SETATTRIBUTEVISTRINGRESPONSE._serialized_end=22380
  _SETNAMEDWAVEFORMNEXTWRITEPOSITIONREQUEST._serialized_start=22383
  _SETNAMEDWAVEFORMNEXTWRITEPOSITIONREQUEST._serialized_end=22617
  _SETNAMEDWAVEFORMNEXTWRITEPOSITIONRESPONSE._serialized_start=22619
  _SETNAMEDWAVEFORMNEXTWRITEPOSITIONRESPONSE._serialized_end=22678
  _SETWAVEFORMNEXTWRITEPOSITIONREQUEST._serialized_start=22681
  _SETWAVEFORMNEXTWRITEPOSITIONREQUEST._serialized_end=22912
  _SETWAVEFORMNEXTWRITEPOSITIONRESPONSE._serialized_start=22914
  _SETWAVEFORMNEXTWRITEPOSITIONRESPONSE._serialized_end=22968
  _WAITUNTILDONEREQUEST._serialized_start=22970
  _WAITUNTILDONEREQUEST._serialized_end=23046
  _WAITUNTILDONERESPONSE._serialized_start=23048
  _WAITUNTILDONERESPONSE._serialized_end=23087
  _WRITEBINARY16WAVEFORMREQUEST._serialized_start=23089
  _WRITEBINARY16WAVEFORMREQUEST._serialized_end=23216
  _WRITEBINARY16WAVEFORMRESPONSE._serialized_start=23218
  _WRITEBINARY16WAVEFORMRESPONSE._serialized_end=23265
  _WRITECOMPLEXBINARY16WAVEFORMREQUEST._serialized_start=23268
  _WRITECOMPLEXBINARY16WAVEFORMREQUEST._serialized_end=23431
  _WRITECOMPLEXBINARY16WAVEFORMRESPONSE._serialized_start=23433
  _WRITECOMPLEXBINARY16WAVEFORMRESPONSE._serialized_end=23487
  _WRITENAMEDWAVEFORMCOMPLEXF64REQUEST._serialized_start=23490
  _WRITENAMEDWAVEFORMCOMPLEXF64REQUEST._serialized_end=23654
  _WRITENAMEDWAVEFORMCOMPLEXF64RESPONSE._serialized_start=23656
  _WRITENAMEDWAVEFORMCOMPLEXF64RESPONSE._serialized_end=23710
  _WRITENAMEDWAVEFORMCOMPLEXI16REQUEST._serialized_start=23713
  _WRITENAMEDWAVEFORMCOMPLEXI16REQUEST._serialized_end=23874
  _WRITENAMEDWAVEFORMCOMPLEXI16RESPONSE._serialized_start=23876
  _WRITENAMEDWAVEFORMCOMPLEXI16RESPONSE._serialized_end=23930
  _WRITENAMEDWAVEFORMF64REQUEST._serialized_start=23932
  _WRITENAMEDWAVEFORMF64REQUEST._serialized_end=24057
  _WRITENAMEDWAVEFORMF64RESPONSE._serialized_start=24059
  _WRITENAMEDWAVEFORMF64RESPONSE._serialized_end=24106
  _WRITENAMEDWAVEFORMI16REQUEST._serialized_start=24108
  _WRITENAMEDWAVEFORMI16REQUEST._serialized_end=24233
  _WRITENAMEDWAVEFORMI16RESPONSE._serialized_start=24235
  _WRITENAMEDWAVEFORMI16RESPONSE._serialized_end=24282
  _WRITEP2PENDPOINTI16REQUEST._serialized_start=24284
  _WRITEP2PENDPOINTI16REQUEST._serialized_end=24394
  _WRITEP2PENDPOINTI16RESPONSE._serialized_start=24396
  _WRITEP2PENDPOINTI16RESPONSE._serialized_end=24441
  _WRITESCRIPTREQUEST._serialized_start=24443
  _WRITESCRIPTREQUEST._serialized_end=24537
  _WRITESCRIPTRESPONSE._serialized_start=24539
  _WRITESCRIPTRESPONSE._serialized_end=24576
  _WRITEWAVEFORMREQUEST._serialized_start=24578
  _WRITEWAVEFORMREQUEST._serialized_end=24697
  _WRITEWAVEFORMRESPONSE._serialized_start=24699
  _WRITEWAVEFORMRESPONSE._serialized_end=24738
  _WRITEWAVEFORMCOMPLEXF64REQUEST._serialized_start=24741
  _WRITEWAVEFORMCOMPLEXF64REQUEST._serialized_end=24902
  _WRITEWAVEFORMCOMPLEXF64RESPONSE._serialized_start=24904
  _WRITEWAVEFORMCOMPLEXF64RESPONSE._serialized_end=24953
  _NIFGEN._serialized_start=51600
  _NIFGEN._serialized_end=66007
# @@protoc_insertion_point(module_scope)
